import enum

from .win32_filetime import dt_to_filetime, filetime_to_dt, filetime_now

# Security descriptor conversion
# see https://docs.microsoft.com/en-us/windows/desktop/api/sddl/nf-sddl-convertstringsecuritydescriptortosecuritydescriptorw
from .bindings import ffi, lib


# TODO: should use `lib.LocalFree` to free generated security descriptor at one point
def security_descriptor_factory(str_security_descriptor):
    psd = ffi.new('SECURITY_DESCRIPTOR**')
    psd_size = ffi.new("ULONG*")
    if not lib.ConvertStringSecurityDescriptorToSecurityDescriptorW(
        str_security_descriptor, lib.WFSPY_STRING_SECURITY_DESCRIPTOR_REVISION,
        psd, psd_size):
        raise RuntimeError(f'error: {cook_ntstatus(lib.GetLastError())}')
    # assert lib.IsValidSecurityDescriptor(psd[0])
    return psd[0], psd_size[0]


class FILE_ATTRIBUTE(enum.IntEnum):
    """
    NT File attributes
    see https://docs.microsoft.com/en-us/dotnet/api/system.io.fileattributes
    """

    FILE_ATTRIBUTE_ARCHIVE = 0x20
    FILE_ATTRIBUTE_COMPRESSED = 0x800
    FILE_ATTRIBUTE_DEVICE = 0x40
    FILE_ATTRIBUTE_DIRECTORY = 0x10
    FILE_ATTRIBUTE_ENCRYPTED = 0x4000
    FILE_ATTRIBUTE_HIDDEN = 0x2
    FILE_ATTRIBUTE_INTEGRITY_STREAM = 0x8000
    FILE_ATTRIBUTE_NORMAL = 0x80
    FILE_ATTRIBUTE_NOT_CONTENT_INDEXED = 0x2000
    FILE_ATTRIBUTE_NO_SCRUB_DATA = 0x20000
    FILE_ATTRIBUTE_OFFLINE = 0x1000
    FILE_ATTRIBUTE_READONLY = 0x1
    FILE_ATTRIBUTE_RECALL_ON_DATA_ACCESS = 0x400000
    FILE_ATTRIBUTE_RECALL_ON_OPEN = 0x40000
    FILE_ATTRIBUTE_REPARSE_POINT = 0x400
    FILE_ATTRIBUTE_SPARSE_FILE = 0x200
    FILE_ATTRIBUTE_SYSTEM = 0x4
    FILE_ATTRIBUTE_TEMPORARY = 0x100
    FILE_ATTRIBUTE_VIRTUAL = 0x10000

    INVALID_FILE_ATTRIBUTES = lib.WFSPY_FILE_ATTRIBUTE_INVALID_FILE_ATTRIBUTES




class CREATE_FILE_CREATE_OPTIONS(enum.IntEnum):
    """
    `NtCreateFile`'s CreateOptions flags
    see https://docs.microsoft.com/en-us/windows/desktop/api/winternl/nf-winternl-ntcreatefile
    """

    FILE_DIRECTORY_FILE = lib.WFSPY_FILE_DIRECTORY_FILE
    FILE_NON_DIRECTORY_FILE = lib.WFSPY_FILE_NON_DIRECTORY_FILE
    FILE_WRITE_THROUGH = lib.WFSPY_FILE_WRITE_THROUGH
    FILE_SEQUENTIAL_ONLY = lib.WFSPY_FILE_SEQUENTIAL_ONLY
    FILE_RANDOM_ACCESS = lib.WFSPY_FILE_RANDOM_ACCESS
    FILE_NO_INTERMEDIATE_BUFFERING = lib.WFSPY_FILE_NO_INTERMEDIATE_BUFFERING
    FILE_SYNCHRONOUS_IO_ALERT = lib.WFSPY_FILE_SYNCHRONOUS_IO_ALERT
    FILE_SYNCHRONOUS_IO_NONALERT = lib.WFSPY_FILE_SYNCHRONOUS_IO_NONALERT
    FILE_CREATE_TREE_CONNECTION = lib.WFSPY_FILE_CREATE_TREE_CONNECTION
    FILE_NO_EA_KNOWLEDGE = lib.WFSPY_FILE_NO_EA_KNOWLEDGE
    FILE_OPEN_REPARSE_POINT = lib.WFSPY_FILE_OPEN_REPARSE_POINT
    FILE_DELETE_ON_CLOSE = lib.WFSPY_FILE_DELETE_ON_CLOSE
    FILE_OPEN_BY_FILE_ID = lib.WFSPY_FILE_OPEN_BY_FILE_ID
    FILE_OPEN_FOR_BACKUP_INTENT = lib.WFSPY_FILE_OPEN_FOR_BACKUP_INTENT
    FILE_RESERVE_OPFILTER = lib.WFSPY_FILE_RESERVE_OPFILTER
    FILE_OPEN_REQUIRING_OPLOCK = lib.WFSPY_FILE_OPEN_REQUIRING_OPLOCK
    FILE_COMPLETE_IF_OPLOCKED = lib.WFSPY_FILE_COMPLETE_IF_OPLOCKED


# NT status codes, legend says there is one for each moment in life ;-)
# see https://docs.microsoft.com/en-us/openspecs/windows_protocols/ms-erref/596a1078-e883-4972-9bbc-49e60bebca55


def nt_success(status):
    """
    Evaluates to TRUE if the return value specified by Status is a success
    type (0 − 0x3FFFFFFF) or an informational type (0x40000000 − 0x7FFFFFFF).
    """
    return 0 <= status <= 0x3FFFFFFF or 0x40000000 <= status <= 0x7FFFFFFF


def nt_information(status):
    """
    Evaluates to TRUE if the return value specified by Status is an
    informational type (0x40000000 − 0x7FFFFFFF).
    """
    return 0x40000000 <= status <= 0x7FFFFFFF


def nt_warning(status):
    """
    Evaluates to TRUE if the return value specified by Status is a warning
    type (0x80000000 − 0xBFFFFFFF).
    """
    return 0x80000000 <= status <= 0xBFFFFFFF


def nt_error(status):
    """
    Evaluates to TRUE if the return value specified by Status is an error
    type (0xC0000000 - 0xFFFFFFFF).
    """
    return 0xC0000000 <= status <= 0xFFFFFFFF


def cook_ntstatus(status):
    for candidate in NTSTATUS:
        if candidate.value == status:
            return candidate


class NTSTATUS(enum.IntEnum):
    STATUS_SUCCESS = 0x0
    STATUS_WAIT_0 = 0x0
    STATUS_WAIT_1 = 0x1
    STATUS_WAIT_2 = 0x2
    STATUS_WAIT_3 = 0x3
    STATUS_WAIT_63 = 0x3f
    STATUS_ABANDONED = 0x80
    STATUS_ABANDONED_WAIT_0 = 0x80
    STATUS_ABANDONED_WAIT_63 = 0xbf
    STATUS_USER_APC = 0xc0
    STATUS_ALERTED = 0x101
    STATUS_TIMEOUT = 0x102
    STATUS_PENDING = 0x103
    STATUS_REPARSE = 0x104
    STATUS_MORE_ENTRIES = 0x105
    STATUS_NOT_ALL_ASSIGNED = 0x106
    STATUS_SOME_NOT_MAPPED = 0x107
    STATUS_OPLOCK_BREAK_IN_PROGRESS = 0x108
    STATUS_VOLUME_MOUNTED = 0x109
    STATUS_RXACT_COMMITTED = 0x10a
    STATUS_NOTIFY_CLEANUP = 0x10b
    STATUS_NOTIFY_ENUM_DIR = 0x10c
    STATUS_NO_QUOTAS_FOR_ACCOUNT = 0x10d
    STATUS_PRIMARY_TRANSPORT_CONNECT_FAILED = 0x10e
    STATUS_PAGE_FAULT_TRANSITION = 0x110
    STATUS_PAGE_FAULT_DEMAND_ZERO = 0x111
    STATUS_PAGE_FAULT_COPY_ON_WRITE = 0x112
    STATUS_PAGE_FAULT_GUARD_PAGE = 0x113
    STATUS_PAGE_FAULT_PAGING_FILE = 0x114
    STATUS_CACHE_PAGE_LOCKED = 0x115
    STATUS_CRASH_DUMP = 0x116
    STATUS_BUFFER_ALL_ZEROS = 0x117
    STATUS_REPARSE_OBJECT = 0x118
    STATUS_RESOURCE_REQUIREMENTS_CHANGED = 0x119
    STATUS_TRANSLATION_COMPLETE = 0x120
    STATUS_DS_MEMBERSHIP_EVALUATED_LOCALLY = 0x121
    STATUS_NOTHING_TO_TERMINATE = 0x122
    STATUS_PROCESS_NOT_IN_JOB = 0x123
    STATUS_PROCESS_IN_JOB = 0x124
    STATUS_VOLSNAP_HIBERNATE_READY = 0x125
    STATUS_FSFILTER_OP_COMPLETED_SUCCESSFULLY = 0x126
    STATUS_INTERRUPT_VECTOR_ALREADY_CONNECTED = 0x127
    STATUS_INTERRUPT_STILL_CONNECTED = 0x128
    STATUS_PROCESS_CLONED = 0x129
    STATUS_FILE_LOCKED_WITH_ONLY_READERS = 0x12a
    STATUS_FILE_LOCKED_WITH_WRITERS = 0x12b
    STATUS_RESOURCEMANAGER_READ_ONLY = 0x202
    STATUS_WAIT_FOR_OPLOCK = 0x367
    DBG_EXCEPTION_HANDLED = 0x10001
    DBG_CONTINUE = 0x10002
    STATUS_FLT_IO_COMPLETE = 0x1c0001
    STATUS_FILE_NOT_AVAILABLE = 0xc0000467
    STATUS_CALLBACK_RETURNED_THREAD_AFFINITY = 0xc0000721
    STATUS_OBJECT_NAME_EXISTS = 0x40000000
    STATUS_THREAD_WAS_SUSPENDED = 0x40000001
    STATUS_WORKING_SET_LIMIT_RANGE = 0x40000002
    STATUS_IMAGE_NOT_AT_BASE = 0x40000003
    STATUS_RXACT_STATE_CREATED = 0x40000004
    STATUS_SEGMENT_NOTIFICATION = 0x40000005
    STATUS_LOCAL_USER_SESSION_KEY = 0x40000006
    STATUS_BAD_CURRENT_DIRECTORY = 0x40000007
    STATUS_SERIAL_MORE_WRITES = 0x40000008
    STATUS_REGISTRY_RECOVERED = 0x40000009
    STATUS_FT_READ_RECOVERY_FROM_BACKUP = 0x4000000a
    STATUS_FT_WRITE_RECOVERY = 0x4000000b
    STATUS_SERIAL_COUNTER_TIMEOUT = 0x4000000c
    STATUS_NULL_LM_PASSWORD = 0x4000000d
    STATUS_IMAGE_MACHINE_TYPE_MISMATCH = 0x4000000e
    STATUS_RECEIVE_PARTIAL = 0x4000000f
    STATUS_RECEIVE_EXPEDITED = 0x40000010
    STATUS_RECEIVE_PARTIAL_EXPEDITED = 0x40000011
    STATUS_EVENT_DONE = 0x40000012
    STATUS_EVENT_PENDING = 0x40000013
    STATUS_CHECKING_FILE_SYSTEM = 0x40000014
    STATUS_FATAL_APP_EXIT = 0x40000015
    STATUS_PREDEFINED_HANDLE = 0x40000016
    STATUS_WAS_UNLOCKED = 0x40000017
    STATUS_SERVICE_NOTIFICATION = 0x40000018
    STATUS_WAS_LOCKED = 0x40000019
    STATUS_LOG_HARD_ERROR = 0x4000001a
    STATUS_ALREADY_WIN32 = 0x4000001b
    STATUS_WX86_UNSIMULATE = 0x4000001c
    STATUS_WX86_CONTINUE = 0x4000001d
    STATUS_WX86_SINGLE_STEP = 0x4000001e
    STATUS_WX86_BREAKPOINT = 0x4000001f
    STATUS_WX86_EXCEPTION_CONTINUE = 0x40000020
    STATUS_WX86_EXCEPTION_LASTCHANCE = 0x40000021
    STATUS_WX86_EXCEPTION_CHAIN = 0x40000022
    STATUS_IMAGE_MACHINE_TYPE_MISMATCH_EXE = 0x40000023
    STATUS_NO_YIELD_PERFORMED = 0x40000024
    STATUS_TIMER_RESUME_IGNORED = 0x40000025
    STATUS_ARBITRATION_UNHANDLED = 0x40000026
    STATUS_CARDBUS_NOT_SUPPORTED = 0x40000027
    STATUS_WX86_CREATEWX86TIB = 0x40000028
    STATUS_MP_PROCESSOR_MISMATCH = 0x40000029
    STATUS_HIBERNATED = 0x4000002a
    STATUS_RESUME_HIBERNATION = 0x4000002b
    STATUS_FIRMWARE_UPDATED = 0x4000002c
    STATUS_DRIVERS_LEAKING_LOCKED_PAGES = 0x4000002d
    STATUS_MESSAGE_RETRIEVED = 0x4000002e
    STATUS_SYSTEM_POWERSTATE_TRANSITION = 0x4000002f
    STATUS_ALPC_CHECK_COMPLETION_LIST = 0x40000030
    STATUS_SYSTEM_POWERSTATE_COMPLEX_TRANSITION = 0x40000031
    STATUS_ACCESS_AUDIT_BY_POLICY = 0x40000032
    STATUS_ABANDON_HIBERFILE = 0x40000033
    STATUS_BIZRULES_NOT_ENABLED = 0x40000034
    STATUS_WAKE_SYSTEM = 0x40000294
    STATUS_DS_SHUTTING_DOWN = 0x40000370
    DBG_REPLY_LATER = 0x40010001
    DBG_UNABLE_TO_PROVIDE_HANDLE = 0x40010002
    DBG_TERMINATE_THREAD = 0x40010003
    DBG_TERMINATE_PROCESS = 0x40010004
    DBG_CONTROL_C = 0x40010005
    DBG_PRINTEXCEPTION_C = 0x40010006
    DBG_RIPEXCEPTION = 0x40010007
    DBG_CONTROL_BREAK = 0x40010008
    DBG_COMMAND_EXCEPTION = 0x40010009
    RPC_NT_UUID_LOCAL_ONLY = 0x40020056
    RPC_NT_SEND_INCOMPLETE = 0x400200af
    STATUS_CTX_CDM_CONNECT = 0x400a0004
    STATUS_CTX_CDM_DISCONNECT = 0x400a0005
    STATUS_SXS_RELEASE_ACTIVATION_CONTEXT = 0x4015000d
    STATUS_RECOVERY_NOT_NEEDED = 0x40190034
    STATUS_RM_ALREADY_STARTED = 0x40190035
    STATUS_LOG_NO_RESTART = 0x401a000c
    STATUS_VIDEO_DRIVER_DEBUG_REPORT_REQUEST = 0x401b00ec
    STATUS_GRAPHICS_PARTIAL_DATA_POPULATED = 0x401e000a
    STATUS_GRAPHICS_DRIVER_MISMATCH = 0x401e0117
    STATUS_GRAPHICS_MODE_NOT_PINNED = 0x401e0307
    STATUS_GRAPHICS_NO_PREFERRED_MODE = 0x401e031e
    STATUS_GRAPHICS_DATASET_IS_EMPTY = 0x401e034b
    STATUS_GRAPHICS_NO_MORE_ELEMENTS_IN_DATASET = 0x401e034c
    STATUS_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_PINNED = 0x401e0351
    STATUS_GRAPHICS_UNKNOWN_CHILD_STATUS = 0x401e042f
    STATUS_GRAPHICS_LEADLINK_START_DEFERRED = 0x401e0437
    STATUS_GRAPHICS_POLLING_TOO_FREQUENTLY = 0x401e0439
    STATUS_GRAPHICS_START_DEFERRED = 0x401e043a
    STATUS_NDIS_INDICATION_REQUIRED = 0x40230001
    STATUS_GUARD_PAGE_VIOLATION = 0x80000001
    STATUS_DATATYPE_MISALIGNMENT = 0x80000002
    STATUS_BREAKPOINT = 0x80000003
    STATUS_SINGLE_STEP = 0x80000004
    STATUS_BUFFER_OVERFLOW = 0x80000005
    STATUS_NO_MORE_FILES = 0x80000006
    STATUS_WAKE_SYSTEM_DEBUGGER = 0x80000007
    STATUS_HANDLES_CLOSED = 0x8000000a
    STATUS_NO_INHERITANCE = 0x8000000b
    STATUS_GUID_SUBSTITUTION_MADE = 0x8000000c
    STATUS_PARTIAL_COPY = 0x8000000d
    STATUS_DEVICE_PAPER_EMPTY = 0x8000000e
    STATUS_DEVICE_POWERED_OFF = 0x8000000f
    STATUS_DEVICE_OFF_LINE = 0x80000010
    STATUS_DEVICE_BUSY = 0x80000011
    STATUS_NO_MORE_EAS = 0x80000012
    STATUS_INVALID_EA_NAME = 0x80000013
    STATUS_EA_LIST_INCONSISTENT = 0x80000014
    STATUS_INVALID_EA_FLAG = 0x80000015
    STATUS_VERIFY_REQUIRED = 0x80000016
    STATUS_EXTRANEOUS_INFORMATION = 0x80000017
    STATUS_RXACT_COMMIT_NECESSARY = 0x80000018
    STATUS_NO_MORE_ENTRIES = 0x8000001a
    STATUS_FILEMARK_DETECTED = 0x8000001b
    STATUS_MEDIA_CHANGED = 0x8000001c
    STATUS_BUS_RESET = 0x8000001d
    STATUS_END_OF_MEDIA = 0x8000001e
    STATUS_BEGINNING_OF_MEDIA = 0x8000001f
    STATUS_MEDIA_CHECK = 0x80000020
    STATUS_SETMARK_DETECTED = 0x80000021
    STATUS_NO_DATA_DETECTED = 0x80000022
    STATUS_REDIRECTOR_HAS_OPEN_HANDLES = 0x80000023
    STATUS_SERVER_HAS_OPEN_HANDLES = 0x80000024
    STATUS_ALREADY_DISCONNECTED = 0x80000025
    STATUS_LONGJUMP = 0x80000026
    STATUS_CLEANER_CARTRIDGE_INSTALLED = 0x80000027
    STATUS_PLUGPLAY_QUERY_VETOED = 0x80000028
    STATUS_UNWIND_CONSOLIDATE = 0x80000029
    STATUS_REGISTRY_HIVE_RECOVERED = 0x8000002a
    STATUS_DLL_MIGHT_BE_INSECURE = 0x8000002b
    STATUS_DLL_MIGHT_BE_INCOMPATIBLE = 0x8000002c
    STATUS_STOPPED_ON_SYMLINK = 0x8000002d
    STATUS_DEVICE_REQUIRES_CLEANING = 0x80000288
    STATUS_DEVICE_DOOR_OPEN = 0x80000289
    STATUS_DATA_LOST_REPAIR = 0x80000803
    DBG_EXCEPTION_NOT_HANDLED = 0x80010001
    STATUS_CLUSTER_NODE_ALREADY_UP = 0x80130001
    STATUS_CLUSTER_NODE_ALREADY_DOWN = 0x80130002
    STATUS_CLUSTER_NETWORK_ALREADY_ONLINE = 0x80130003
    STATUS_CLUSTER_NETWORK_ALREADY_OFFLINE = 0x80130004
    STATUS_CLUSTER_NODE_ALREADY_MEMBER = 0x80130005
    STATUS_COULD_NOT_RESIZE_LOG = 0x80190009
    STATUS_NO_TXF_METADATA = 0x80190029
    STATUS_CANT_RECOVER_WITH_HANDLE_OPEN = 0x80190031
    STATUS_TXF_METADATA_ALREADY_PRESENT = 0x80190041
    STATUS_TRANSACTION_SCOPE_CALLBACKS_NOT_SET = 0x80190042
    STATUS_VIDEO_HUNG_DISPLAY_DRIVER_THREAD_RECOVERED = 0x801b00eb
    STATUS_FLT_BUFFER_TOO_SMALL = 0x801c0001
    STATUS_FVE_PARTIAL_METADATA = 0x80210001
    STATUS_FVE_TRANSIENT_STATE = 0x80210002
    STATUS_UNSUCCESSFUL = 0xc0000001
    STATUS_NOT_IMPLEMENTED = 0xc0000002
    STATUS_INVALID_INFO_CLASS = 0xc0000003
    STATUS_INFO_LENGTH_MISMATCH = 0xc0000004
    STATUS_ACCESS_VIOLATION = 0xc0000005
    STATUS_IN_PAGE_ERROR = 0xc0000006
    STATUS_PAGEFILE_QUOTA = 0xc0000007
    STATUS_INVALID_HANDLE = 0xc0000008
    STATUS_BAD_INITIAL_STACK = 0xc0000009
    STATUS_BAD_INITIAL_PC = 0xc000000a
    STATUS_INVALID_CID = 0xc000000b
    STATUS_TIMER_NOT_CANCELED = 0xc000000c
    STATUS_INVALID_PARAMETER = 0xc000000d
    STATUS_NO_SUCH_DEVICE = 0xc000000e
    STATUS_NO_SUCH_FILE = 0xc000000f
    STATUS_INVALID_DEVICE_REQUEST = 0xc0000010
    STATUS_END_OF_FILE = 0xc0000011
    STATUS_WRONG_VOLUME = 0xc0000012
    STATUS_NO_MEDIA_IN_DEVICE = 0xc0000013
    STATUS_UNRECOGNIZED_MEDIA = 0xc0000014
    STATUS_NONEXISTENT_SECTOR = 0xc0000015
    STATUS_MORE_PROCESSING_REQUIRED = 0xc0000016
    STATUS_NO_MEMORY = 0xc0000017
    STATUS_CONFLICTING_ADDRESSES = 0xc0000018
    STATUS_NOT_MAPPED_VIEW = 0xc0000019
    STATUS_UNABLE_TO_FREE_VM = 0xc000001a
    STATUS_UNABLE_TO_DELETE_SECTION = 0xc000001b
    STATUS_INVALID_SYSTEM_SERVICE = 0xc000001c
    STATUS_ILLEGAL_INSTRUCTION = 0xc000001d
    STATUS_INVALID_LOCK_SEQUENCE = 0xc000001e
    STATUS_INVALID_VIEW_SIZE = 0xc000001f
    STATUS_INVALID_FILE_FOR_SECTION = 0xc0000020
    STATUS_ALREADY_COMMITTED = 0xc0000021
    STATUS_ACCESS_DENIED = 0xc0000022
    STATUS_BUFFER_TOO_SMALL = 0xc0000023
    STATUS_OBJECT_TYPE_MISMATCH = 0xc0000024
    STATUS_NONCONTINUABLE_EXCEPTION = 0xc0000025
    STATUS_INVALID_DISPOSITION = 0xc0000026
    STATUS_UNWIND = 0xc0000027
    STATUS_BAD_STACK = 0xc0000028
    STATUS_INVALID_UNWIND_TARGET = 0xc0000029
    STATUS_NOT_LOCKED = 0xc000002a
    STATUS_PARITY_ERROR = 0xc000002b
    STATUS_UNABLE_TO_DECOMMIT_VM = 0xc000002c
    STATUS_NOT_COMMITTED = 0xc000002d
    STATUS_INVALID_PORT_ATTRIBUTES = 0xc000002e
    STATUS_PORT_MESSAGE_TOO_LONG = 0xc000002f
    STATUS_INVALID_PARAMETER_MIX = 0xc0000030
    STATUS_INVALID_QUOTA_LOWER = 0xc0000031
    STATUS_DISK_CORRUPT_ERROR = 0xc0000032
    STATUS_OBJECT_NAME_INVALID = 0xc0000033
    STATUS_OBJECT_NAME_NOT_FOUND = 0xc0000034
    STATUS_OBJECT_NAME_COLLISION = 0xc0000035
    STATUS_PORT_DISCONNECTED = 0xc0000037
    STATUS_DEVICE_ALREADY_ATTACHED = 0xc0000038
    STATUS_OBJECT_PATH_INVALID = 0xc0000039
    STATUS_OBJECT_PATH_NOT_FOUND = 0xc000003a
    STATUS_OBJECT_PATH_SYNTAX_BAD = 0xc000003b
    STATUS_DATA_OVERRUN = 0xc000003c
    STATUS_DATA_LATE_ERROR = 0xc000003d
    STATUS_DATA_ERROR = 0xc000003e
    STATUS_CRC_ERROR = 0xc000003f
    STATUS_SECTION_TOO_BIG = 0xc0000040
    STATUS_PORT_CONNECTION_REFUSED = 0xc0000041
    STATUS_INVALID_PORT_HANDLE = 0xc0000042
    STATUS_SHARING_VIOLATION = 0xc0000043
    STATUS_QUOTA_EXCEEDED = 0xc0000044
    STATUS_INVALID_PAGE_PROTECTION = 0xc0000045
    STATUS_MUTANT_NOT_OWNED = 0xc0000046
    STATUS_SEMAPHORE_LIMIT_EXCEEDED = 0xc0000047
    STATUS_PORT_ALREADY_SET = 0xc0000048
    STATUS_SECTION_NOT_IMAGE = 0xc0000049
    STATUS_SUSPEND_COUNT_EXCEEDED = 0xc000004a
    STATUS_THREAD_IS_TERMINATING = 0xc000004b
    STATUS_BAD_WORKING_SET_LIMIT = 0xc000004c
    STATUS_INCOMPATIBLE_FILE_MAP = 0xc000004d
    STATUS_SECTION_PROTECTION = 0xc000004e
    STATUS_EAS_NOT_SUPPORTED = 0xc000004f
    STATUS_EA_TOO_LARGE = 0xc0000050
    STATUS_NONEXISTENT_EA_ENTRY = 0xc0000051
    STATUS_NO_EAS_ON_FILE = 0xc0000052
    STATUS_EA_CORRUPT_ERROR = 0xc0000053
    STATUS_FILE_LOCK_CONFLICT = 0xc0000054
    STATUS_LOCK_NOT_GRANTED = 0xc0000055
    STATUS_DELETE_PENDING = 0xc0000056
    STATUS_CTL_FILE_NOT_SUPPORTED = 0xc0000057
    STATUS_UNKNOWN_REVISION = 0xc0000058
    STATUS_REVISION_MISMATCH = 0xc0000059
    STATUS_INVALID_OWNER = 0xc000005a
    STATUS_INVALID_PRIMARY_GROUP = 0xc000005b
    STATUS_NO_IMPERSONATION_TOKEN = 0xc000005c
    STATUS_CANT_DISABLE_MANDATORY = 0xc000005d
    STATUS_NO_LOGON_SERVERS = 0xc000005e
    STATUS_NO_SUCH_LOGON_SESSION = 0xc000005f
    STATUS_NO_SUCH_PRIVILEGE = 0xc0000060
    STATUS_PRIVILEGE_NOT_HELD = 0xc0000061
    STATUS_INVALID_ACCOUNT_NAME = 0xc0000062
    STATUS_USER_EXISTS = 0xc0000063
    STATUS_NO_SUCH_USER = 0xc0000064
    STATUS_GROUP_EXISTS = 0xc0000065
    STATUS_NO_SUCH_GROUP = 0xc0000066
    STATUS_MEMBER_IN_GROUP = 0xc0000067
    STATUS_MEMBER_NOT_IN_GROUP = 0xc0000068
    STATUS_LAST_ADMIN = 0xc0000069
    STATUS_WRONG_PASSWORD = 0xc000006a
    STATUS_ILL_FORMED_PASSWORD = 0xc000006b
    STATUS_PASSWORD_RESTRICTION = 0xc000006c
    STATUS_LOGON_FAILURE = 0xc000006d
    STATUS_ACCOUNT_RESTRICTION = 0xc000006e
    STATUS_INVALID_LOGON_HOURS = 0xc000006f
    STATUS_INVALID_WORKSTATION = 0xc0000070
    STATUS_PASSWORD_EXPIRED = 0xc0000071
    STATUS_ACCOUNT_DISABLED = 0xc0000072
    STATUS_NONE_MAPPED = 0xc0000073
    STATUS_TOO_MANY_LUIDS_REQUESTED = 0xc0000074
    STATUS_LUIDS_EXHAUSTED = 0xc0000075
    STATUS_INVALID_SUB_AUTHORITY = 0xc0000076
    STATUS_INVALID_ACL = 0xc0000077
    STATUS_INVALID_SID = 0xc0000078
    STATUS_INVALID_SECURITY_DESCR = 0xc0000079
    STATUS_PROCEDURE_NOT_FOUND = 0xc000007a
    STATUS_INVALID_IMAGE_FORMAT = 0xc000007b
    STATUS_NO_TOKEN = 0xc000007c
    STATUS_BAD_INHERITANCE_ACL = 0xc000007d
    STATUS_RANGE_NOT_LOCKED = 0xc000007e
    STATUS_DISK_FULL = 0xc000007f
    STATUS_SERVER_DISABLED = 0xc0000080
    STATUS_SERVER_NOT_DISABLED = 0xc0000081
    STATUS_TOO_MANY_GUIDS_REQUESTED = 0xc0000082
    STATUS_GUIDS_EXHAUSTED = 0xc0000083
    STATUS_INVALID_ID_AUTHORITY = 0xc0000084
    STATUS_AGENTS_EXHAUSTED = 0xc0000085
    STATUS_INVALID_VOLUME_LABEL = 0xc0000086
    STATUS_SECTION_NOT_EXTENDED = 0xc0000087
    STATUS_NOT_MAPPED_DATA = 0xc0000088
    STATUS_RESOURCE_DATA_NOT_FOUND = 0xc0000089
    STATUS_RESOURCE_TYPE_NOT_FOUND = 0xc000008a
    STATUS_RESOURCE_NAME_NOT_FOUND = 0xc000008b
    STATUS_ARRAY_BOUNDS_EXCEEDED = 0xc000008c
    STATUS_FLOAT_DENORMAL_OPERAND = 0xc000008d
    STATUS_FLOAT_DIVIDE_BY_ZERO = 0xc000008e
    STATUS_FLOAT_INEXACT_RESULT = 0xc000008f
    STATUS_FLOAT_INVALID_OPERATION = 0xc0000090
    STATUS_FLOAT_OVERFLOW = 0xc0000091
    STATUS_FLOAT_STACK_CHECK = 0xc0000092
    STATUS_FLOAT_UNDERFLOW = 0xc0000093
    STATUS_INTEGER_DIVIDE_BY_ZERO = 0xc0000094
    STATUS_INTEGER_OVERFLOW = 0xc0000095
    STATUS_PRIVILEGED_INSTRUCTION = 0xc0000096
    STATUS_TOO_MANY_PAGING_FILES = 0xc0000097
    STATUS_FILE_INVALID = 0xc0000098
    STATUS_ALLOTTED_SPACE_EXCEEDED = 0xc0000099
    STATUS_INSUFFICIENT_RESOURCES = 0xc000009a
    STATUS_DFS_EXIT_PATH_FOUND = 0xc000009b
    STATUS_DEVICE_DATA_ERROR = 0xc000009c
    STATUS_DEVICE_NOT_CONNECTED = 0xc000009d
    STATUS_FREE_VM_NOT_AT_BASE = 0xc000009f
    STATUS_MEMORY_NOT_ALLOCATED = 0xc00000a0
    STATUS_WORKING_SET_QUOTA = 0xc00000a1
    STATUS_MEDIA_WRITE_PROTECTED = 0xc00000a2
    STATUS_DEVICE_NOT_READY = 0xc00000a3
    STATUS_INVALID_GROUP_ATTRIBUTES = 0xc00000a4
    STATUS_BAD_IMPERSONATION_LEVEL = 0xc00000a5
    STATUS_CANT_OPEN_ANONYMOUS = 0xc00000a6
    STATUS_BAD_VALIDATION_CLASS = 0xc00000a7
    STATUS_BAD_TOKEN_TYPE = 0xc00000a8
    STATUS_BAD_MASTER_BOOT_RECORD = 0xc00000a9
    STATUS_INSTRUCTION_MISALIGNMENT = 0xc00000aa
    STATUS_INSTANCE_NOT_AVAILABLE = 0xc00000ab
    STATUS_PIPE_NOT_AVAILABLE = 0xc00000ac
    STATUS_INVALID_PIPE_STATE = 0xc00000ad
    STATUS_PIPE_BUSY = 0xc00000ae
    STATUS_ILLEGAL_FUNCTION = 0xc00000af
    STATUS_PIPE_DISCONNECTED = 0xc00000b0
    STATUS_PIPE_CLOSING = 0xc00000b1
    STATUS_PIPE_CONNECTED = 0xc00000b2
    STATUS_PIPE_LISTENING = 0xc00000b3
    STATUS_INVALID_READ_MODE = 0xc00000b4
    STATUS_IO_TIMEOUT = 0xc00000b5
    STATUS_FILE_FORCED_CLOSED = 0xc00000b6
    STATUS_PROFILING_NOT_STARTED = 0xc00000b7
    STATUS_PROFILING_NOT_STOPPED = 0xc00000b8
    STATUS_COULD_NOT_INTERPRET = 0xc00000b9
    STATUS_FILE_IS_A_DIRECTORY = 0xc00000ba
    STATUS_NOT_SUPPORTED = 0xc00000bb
    STATUS_REMOTE_NOT_LISTENING = 0xc00000bc
    STATUS_DUPLICATE_NAME = 0xc00000bd
    STATUS_BAD_NETWORK_PATH = 0xc00000be
    STATUS_NETWORK_BUSY = 0xc00000bf
    STATUS_DEVICE_DOES_NOT_EXIST = 0xc00000c0
    STATUS_TOO_MANY_COMMANDS = 0xc00000c1
    STATUS_ADAPTER_HARDWARE_ERROR = 0xc00000c2
    STATUS_INVALID_NETWORK_RESPONSE = 0xc00000c3
    STATUS_UNEXPECTED_NETWORK_ERROR = 0xc00000c4
    STATUS_BAD_REMOTE_ADAPTER = 0xc00000c5
    STATUS_PRINT_QUEUE_FULL = 0xc00000c6
    STATUS_NO_SPOOL_SPACE = 0xc00000c7
    STATUS_PRINT_CANCELLED = 0xc00000c8
    STATUS_NETWORK_NAME_DELETED = 0xc00000c9
    STATUS_NETWORK_ACCESS_DENIED = 0xc00000ca
    STATUS_BAD_DEVICE_TYPE = 0xc00000cb
    STATUS_BAD_NETWORK_NAME = 0xc00000cc
    STATUS_TOO_MANY_NAMES = 0xc00000cd
    STATUS_TOO_MANY_SESSIONS = 0xc00000ce
    STATUS_SHARING_PAUSED = 0xc00000cf
    STATUS_REQUEST_NOT_ACCEPTED = 0xc00000d0
    STATUS_REDIRECTOR_PAUSED = 0xc00000d1
    STATUS_NET_WRITE_FAULT = 0xc00000d2
    STATUS_PROFILING_AT_LIMIT = 0xc00000d3
    STATUS_NOT_SAME_DEVICE = 0xc00000d4
    STATUS_FILE_RENAMED = 0xc00000d5
    STATUS_VIRTUAL_CIRCUIT_CLOSED = 0xc00000d6
    STATUS_NO_SECURITY_ON_OBJECT = 0xc00000d7
    STATUS_CANT_WAIT = 0xc00000d8
    STATUS_PIPE_EMPTY = 0xc00000d9
    STATUS_CANT_ACCESS_DOMAIN_INFO = 0xc00000da
    STATUS_CANT_TERMINATE_SELF = 0xc00000db
    STATUS_INVALID_SERVER_STATE = 0xc00000dc
    STATUS_INVALID_DOMAIN_STATE = 0xc00000dd
    STATUS_INVALID_DOMAIN_ROLE = 0xc00000de
    STATUS_NO_SUCH_DOMAIN = 0xc00000df
    STATUS_DOMAIN_EXISTS = 0xc00000e0
    STATUS_DOMAIN_LIMIT_EXCEEDED = 0xc00000e1
    STATUS_OPLOCK_NOT_GRANTED = 0xc00000e2
    STATUS_INVALID_OPLOCK_PROTOCOL = 0xc00000e3
    STATUS_INTERNAL_DB_CORRUPTION = 0xc00000e4
    STATUS_INTERNAL_ERROR = 0xc00000e5
    STATUS_GENERIC_NOT_MAPPED = 0xc00000e6
    STATUS_BAD_DESCRIPTOR_FORMAT = 0xc00000e7
    STATUS_INVALID_USER_BUFFER = 0xc00000e8
    STATUS_UNEXPECTED_IO_ERROR = 0xc00000e9
    STATUS_UNEXPECTED_MM_CREATE_ERR = 0xc00000ea
    STATUS_UNEXPECTED_MM_MAP_ERROR = 0xc00000eb
    STATUS_UNEXPECTED_MM_EXTEND_ERR = 0xc00000ec
    STATUS_NOT_LOGON_PROCESS = 0xc00000ed
    STATUS_LOGON_SESSION_EXISTS = 0xc00000ee
    STATUS_INVALID_PARAMETER_1 = 0xc00000ef
    STATUS_INVALID_PARAMETER_2 = 0xc00000f0
    STATUS_INVALID_PARAMETER_3 = 0xc00000f1
    STATUS_INVALID_PARAMETER_4 = 0xc00000f2
    STATUS_INVALID_PARAMETER_5 = 0xc00000f3
    STATUS_INVALID_PARAMETER_6 = 0xc00000f4
    STATUS_INVALID_PARAMETER_7 = 0xc00000f5
    STATUS_INVALID_PARAMETER_8 = 0xc00000f6
    STATUS_INVALID_PARAMETER_9 = 0xc00000f7
    STATUS_INVALID_PARAMETER_10 = 0xc00000f8
    STATUS_INVALID_PARAMETER_11 = 0xc00000f9
    STATUS_INVALID_PARAMETER_12 = 0xc00000fa
    STATUS_REDIRECTOR_NOT_STARTED = 0xc00000fb
    STATUS_REDIRECTOR_STARTED = 0xc00000fc
    STATUS_STACK_OVERFLOW = 0xc00000fd
    STATUS_NO_SUCH_PACKAGE = 0xc00000fe
    STATUS_BAD_FUNCTION_TABLE = 0xc00000ff
    STATUS_VARIABLE_NOT_FOUND = 0xc0000100
    STATUS_DIRECTORY_NOT_EMPTY = 0xc0000101
    STATUS_FILE_CORRUPT_ERROR = 0xc0000102
    STATUS_NOT_A_DIRECTORY = 0xc0000103
    STATUS_BAD_LOGON_SESSION_STATE = 0xc0000104
    STATUS_LOGON_SESSION_COLLISION = 0xc0000105
    STATUS_NAME_TOO_LONG = 0xc0000106
    STATUS_FILES_OPEN = 0xc0000107
    STATUS_CONNECTION_IN_USE = 0xc0000108
    STATUS_MESSAGE_NOT_FOUND = 0xc0000109
    STATUS_PROCESS_IS_TERMINATING = 0xc000010a
    STATUS_INVALID_LOGON_TYPE = 0xc000010b
    STATUS_NO_GUID_TRANSLATION = 0xc000010c
    STATUS_CANNOT_IMPERSONATE = 0xc000010d
    STATUS_IMAGE_ALREADY_LOADED = 0xc000010e
    STATUS_NO_LDT = 0xc0000117
    STATUS_INVALID_LDT_SIZE = 0xc0000118
    STATUS_INVALID_LDT_OFFSET = 0xc0000119
    STATUS_INVALID_LDT_DESCRIPTOR = 0xc000011a
    STATUS_INVALID_IMAGE_NE_FORMAT = 0xc000011b
    STATUS_RXACT_INVALID_STATE = 0xc000011c
    STATUS_RXACT_COMMIT_FAILURE = 0xc000011d
    STATUS_MAPPED_FILE_SIZE_ZERO = 0xc000011e
    STATUS_TOO_MANY_OPENED_FILES = 0xc000011f
    STATUS_CANCELLED = 0xc0000120
    STATUS_CANNOT_DELETE = 0xc0000121
    STATUS_INVALID_COMPUTER_NAME = 0xc0000122
    STATUS_FILE_DELETED = 0xc0000123
    STATUS_SPECIAL_ACCOUNT = 0xc0000124
    STATUS_SPECIAL_GROUP = 0xc0000125
    STATUS_SPECIAL_USER = 0xc0000126
    STATUS_MEMBERS_PRIMARY_GROUP = 0xc0000127
    STATUS_FILE_CLOSED = 0xc0000128
    STATUS_TOO_MANY_THREADS = 0xc0000129
    STATUS_THREAD_NOT_IN_PROCESS = 0xc000012a
    STATUS_TOKEN_ALREADY_IN_USE = 0xc000012b
    STATUS_PAGEFILE_QUOTA_EXCEEDED = 0xc000012c
    STATUS_COMMITMENT_LIMIT = 0xc000012d
    STATUS_INVALID_IMAGE_LE_FORMAT = 0xc000012e
    STATUS_INVALID_IMAGE_NOT_MZ = 0xc000012f
    STATUS_INVALID_IMAGE_PROTECT = 0xc0000130
    STATUS_INVALID_IMAGE_WIN_16 = 0xc0000131
    STATUS_LOGON_SERVER_CONFLICT = 0xc0000132
    STATUS_TIME_DIFFERENCE_AT_DC = 0xc0000133
    STATUS_SYNCHRONIZATION_REQUIRED = 0xc0000134
    STATUS_DLL_NOT_FOUND = 0xc0000135
    STATUS_OPEN_FAILED = 0xc0000136
    STATUS_IO_PRIVILEGE_FAILED = 0xc0000137
    STATUS_ORDINAL_NOT_FOUND = 0xc0000138
    STATUS_ENTRYPOINT_NOT_FOUND = 0xc0000139
    STATUS_CONTROL_C_EXIT = 0xc000013a
    STATUS_LOCAL_DISCONNECT = 0xc000013b
    STATUS_REMOTE_DISCONNECT = 0xc000013c
    STATUS_REMOTE_RESOURCES = 0xc000013d
    STATUS_LINK_FAILED = 0xc000013e
    STATUS_LINK_TIMEOUT = 0xc000013f
    STATUS_INVALID_CONNECTION = 0xc0000140
    STATUS_INVALID_ADDRESS = 0xc0000141
    STATUS_DLL_INIT_FAILED = 0xc0000142
    STATUS_MISSING_SYSTEMFILE = 0xc0000143
    STATUS_UNHANDLED_EXCEPTION = 0xc0000144
    STATUS_APP_INIT_FAILURE = 0xc0000145
    STATUS_PAGEFILE_CREATE_FAILED = 0xc0000146
    STATUS_NO_PAGEFILE = 0xc0000147
    STATUS_INVALID_LEVEL = 0xc0000148
    STATUS_WRONG_PASSWORD_CORE = 0xc0000149
    STATUS_ILLEGAL_FLOAT_CONTEXT = 0xc000014a
    STATUS_PIPE_BROKEN = 0xc000014b
    STATUS_REGISTRY_CORRUPT = 0xc000014c
    STATUS_REGISTRY_IO_FAILED = 0xc000014d
    STATUS_NO_EVENT_PAIR = 0xc000014e
    STATUS_UNRECOGNIZED_VOLUME = 0xc000014f
    STATUS_SERIAL_NO_DEVICE_INITED = 0xc0000150
    STATUS_NO_SUCH_ALIAS = 0xc0000151
    STATUS_MEMBER_NOT_IN_ALIAS = 0xc0000152
    STATUS_MEMBER_IN_ALIAS = 0xc0000153
    STATUS_ALIAS_EXISTS = 0xc0000154
    STATUS_LOGON_NOT_GRANTED = 0xc0000155
    STATUS_TOO_MANY_SECRETS = 0xc0000156
    STATUS_SECRET_TOO_LONG = 0xc0000157
    STATUS_INTERNAL_DB_ERROR = 0xc0000158
    STATUS_FULLSCREEN_MODE = 0xc0000159
    STATUS_TOO_MANY_CONTEXT_IDS = 0xc000015a
    STATUS_LOGON_TYPE_NOT_GRANTED = 0xc000015b
    STATUS_NOT_REGISTRY_FILE = 0xc000015c
    STATUS_NT_CROSS_ENCRYPTION_REQUIRED = 0xc000015d
    STATUS_DOMAIN_CTRLR_CONFIG_ERROR = 0xc000015e
    STATUS_FT_MISSING_MEMBER = 0xc000015f
    STATUS_ILL_FORMED_SERVICE_ENTRY = 0xc0000160
    STATUS_ILLEGAL_CHARACTER = 0xc0000161
    STATUS_UNMAPPABLE_CHARACTER = 0xc0000162
    STATUS_UNDEFINED_CHARACTER = 0xc0000163
    STATUS_FLOPPY_VOLUME = 0xc0000164
    STATUS_FLOPPY_ID_MARK_NOT_FOUND = 0xc0000165
    STATUS_FLOPPY_WRONG_CYLINDER = 0xc0000166
    STATUS_FLOPPY_UNKNOWN_ERROR = 0xc0000167
    STATUS_FLOPPY_BAD_REGISTERS = 0xc0000168
    STATUS_DISK_RECALIBRATE_FAILED = 0xc0000169
    STATUS_DISK_OPERATION_FAILED = 0xc000016a
    STATUS_DISK_RESET_FAILED = 0xc000016b
    STATUS_SHARED_IRQ_BUSY = 0xc000016c
    STATUS_FT_ORPHANING = 0xc000016d
    STATUS_BIOS_FAILED_TO_CONNECT_INTERRUPT = 0xc000016e
    STATUS_PARTITION_FAILURE = 0xc0000172
    STATUS_INVALID_BLOCK_LENGTH = 0xc0000173
    STATUS_DEVICE_NOT_PARTITIONED = 0xc0000174
    STATUS_UNABLE_TO_LOCK_MEDIA = 0xc0000175
    STATUS_UNABLE_TO_UNLOAD_MEDIA = 0xc0000176
    STATUS_EOM_OVERFLOW = 0xc0000177
    STATUS_NO_MEDIA = 0xc0000178
    STATUS_NO_SUCH_MEMBER = 0xc000017a
    STATUS_INVALID_MEMBER = 0xc000017b
    STATUS_KEY_DELETED = 0xc000017c
    STATUS_NO_LOG_SPACE = 0xc000017d
    STATUS_TOO_MANY_SIDS = 0xc000017e
    STATUS_LM_CROSS_ENCRYPTION_REQUIRED = 0xc000017f
    STATUS_KEY_HAS_CHILDREN = 0xc0000180
    STATUS_CHILD_MUST_BE_VOLATILE = 0xc0000181
    STATUS_DEVICE_CONFIGURATION_ERROR = 0xc0000182
    STATUS_DRIVER_INTERNAL_ERROR = 0xc0000183
    STATUS_INVALID_DEVICE_STATE = 0xc0000184
    STATUS_IO_DEVICE_ERROR = 0xc0000185
    STATUS_DEVICE_PROTOCOL_ERROR = 0xc0000186
    STATUS_BACKUP_CONTROLLER = 0xc0000187
    STATUS_LOG_FILE_FULL = 0xc0000188
    STATUS_TOO_LATE = 0xc0000189
    STATUS_NO_TRUST_LSA_SECRET = 0xc000018a
    STATUS_NO_TRUST_SAM_ACCOUNT = 0xc000018b
    STATUS_TRUSTED_DOMAIN_FAILURE = 0xc000018c
    STATUS_TRUSTED_RELATIONSHIP_FAILURE = 0xc000018d
    STATUS_EVENTLOG_FILE_CORRUPT = 0xc000018e
    STATUS_EVENTLOG_CANT_START = 0xc000018f
    STATUS_TRUST_FAILURE = 0xc0000190
    STATUS_MUTANT_LIMIT_EXCEEDED = 0xc0000191
    STATUS_NETLOGON_NOT_STARTED = 0xc0000192
    STATUS_ACCOUNT_EXPIRED = 0xc0000193
    STATUS_POSSIBLE_DEADLOCK = 0xc0000194
    STATUS_NETWORK_CREDENTIAL_CONFLICT = 0xc0000195
    STATUS_REMOTE_SESSION_LIMIT = 0xc0000196
    STATUS_EVENTLOG_FILE_CHANGED = 0xc0000197
    STATUS_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT = 0xc0000198
    STATUS_NOLOGON_WORKSTATION_TRUST_ACCOUNT = 0xc0000199
    STATUS_NOLOGON_SERVER_TRUST_ACCOUNT = 0xc000019a
    STATUS_DOMAIN_TRUST_INCONSISTENT = 0xc000019b
    STATUS_FS_DRIVER_REQUIRED = 0xc000019c
    STATUS_IMAGE_ALREADY_LOADED_AS_DLL = 0xc000019d
    STATUS_INCOMPATIBLE_WITH_GLOBAL_SHORT_NAME_REGISTRY_SETTING = 0xc000019e
    STATUS_SHORT_NAMES_NOT_ENABLED_ON_VOLUME = 0xc000019f
    STATUS_SECURITY_STREAM_IS_INCONSISTENT = 0xc00001a0
    STATUS_INVALID_LOCK_RANGE = 0xc00001a1
    STATUS_INVALID_ACE_CONDITION = 0xc00001a2
    STATUS_IMAGE_SUBSYSTEM_NOT_PRESENT = 0xc00001a3
    STATUS_NOTIFICATION_GUID_ALREADY_DEFINED = 0xc00001a4
    STATUS_NETWORK_OPEN_RESTRICTION = 0xc0000201
    STATUS_NO_USER_SESSION_KEY = 0xc0000202
    STATUS_USER_SESSION_DELETED = 0xc0000203
    STATUS_RESOURCE_LANG_NOT_FOUND = 0xc0000204
    STATUS_INSUFF_SERVER_RESOURCES = 0xc0000205
    STATUS_INVALID_BUFFER_SIZE = 0xc0000206
    STATUS_INVALID_ADDRESS_COMPONENT = 0xc0000207
    STATUS_INVALID_ADDRESS_WILDCARD = 0xc0000208
    STATUS_TOO_MANY_ADDRESSES = 0xc0000209
    STATUS_ADDRESS_ALREADY_EXISTS = 0xc000020a
    STATUS_ADDRESS_CLOSED = 0xc000020b
    STATUS_CONNECTION_DISCONNECTED = 0xc000020c
    STATUS_CONNECTION_RESET = 0xc000020d
    STATUS_TOO_MANY_NODES = 0xc000020e
    STATUS_TRANSACTION_ABORTED = 0xc000020f
    STATUS_TRANSACTION_TIMED_OUT = 0xc0000210
    STATUS_TRANSACTION_NO_RELEASE = 0xc0000211
    STATUS_TRANSACTION_NO_MATCH = 0xc0000212
    STATUS_TRANSACTION_RESPONDED = 0xc0000213
    STATUS_TRANSACTION_INVALID_ID = 0xc0000214
    STATUS_TRANSACTION_INVALID_TYPE = 0xc0000215
    STATUS_NOT_SERVER_SESSION = 0xc0000216
    STATUS_NOT_CLIENT_SESSION = 0xc0000217
    STATUS_CANNOT_LOAD_REGISTRY_FILE = 0xc0000218
    STATUS_DEBUG_ATTACH_FAILED = 0xc0000219
    STATUS_SYSTEM_PROCESS_TERMINATED = 0xc000021a
    STATUS_DATA_NOT_ACCEPTED = 0xc000021b
    STATUS_NO_BROWSER_SERVERS_FOUND = 0xc000021c
    STATUS_VDM_HARD_ERROR = 0xc000021d
    STATUS_DRIVER_CANCEL_TIMEOUT = 0xc000021e
    STATUS_REPLY_MESSAGE_MISMATCH = 0xc000021f
    STATUS_MAPPED_ALIGNMENT = 0xc0000220
    STATUS_IMAGE_CHECKSUM_MISMATCH = 0xc0000221
    STATUS_LOST_WRITEBEHIND_DATA = 0xc0000222
    STATUS_CLIENT_SERVER_PARAMETERS_INVALID = 0xc0000223
    STATUS_PASSWORD_MUST_CHANGE = 0xc0000224
    STATUS_NOT_FOUND = 0xc0000225
    STATUS_NOT_TINY_STREAM = 0xc0000226
    STATUS_RECOVERY_FAILURE = 0xc0000227
    STATUS_STACK_OVERFLOW_READ = 0xc0000228
    STATUS_FAIL_CHECK = 0xc0000229
    STATUS_DUPLICATE_OBJECTID = 0xc000022a
    STATUS_OBJECTID_EXISTS = 0xc000022b
    STATUS_CONVERT_TO_LARGE = 0xc000022c
    STATUS_RETRY = 0xc000022d
    STATUS_FOUND_OUT_OF_SCOPE = 0xc000022e
    STATUS_ALLOCATE_BUCKET = 0xc000022f
    STATUS_PROPSET_NOT_FOUND = 0xc0000230
    STATUS_MARSHALL_OVERFLOW = 0xc0000231
    STATUS_INVALID_VARIANT = 0xc0000232
    STATUS_DOMAIN_CONTROLLER_NOT_FOUND = 0xc0000233
    STATUS_ACCOUNT_LOCKED_OUT = 0xc0000234
    STATUS_HANDLE_NOT_CLOSABLE = 0xc0000235
    STATUS_CONNECTION_REFUSED = 0xc0000236
    STATUS_GRACEFUL_DISCONNECT = 0xc0000237
    STATUS_ADDRESS_ALREADY_ASSOCIATED = 0xc0000238
    STATUS_ADDRESS_NOT_ASSOCIATED = 0xc0000239
    STATUS_CONNECTION_INVALID = 0xc000023a
    STATUS_CONNECTION_ACTIVE = 0xc000023b
    STATUS_NETWORK_UNREACHABLE = 0xc000023c
    STATUS_HOST_UNREACHABLE = 0xc000023d
    STATUS_PROTOCOL_UNREACHABLE = 0xc000023e
    STATUS_PORT_UNREACHABLE = 0xc000023f
    STATUS_REQUEST_ABORTED = 0xc0000240
    STATUS_CONNECTION_ABORTED = 0xc0000241
    STATUS_BAD_COMPRESSION_BUFFER = 0xc0000242
    STATUS_USER_MAPPED_FILE = 0xc0000243
    STATUS_AUDIT_FAILED = 0xc0000244
    STATUS_TIMER_RESOLUTION_NOT_SET = 0xc0000245
    STATUS_CONNECTION_COUNT_LIMIT = 0xc0000246
    STATUS_LOGIN_TIME_RESTRICTION = 0xc0000247
    STATUS_LOGIN_WKSTA_RESTRICTION = 0xc0000248
    STATUS_IMAGE_MP_UP_MISMATCH = 0xc0000249
    STATUS_INSUFFICIENT_LOGON_INFO = 0xc0000250
    STATUS_BAD_DLL_ENTRYPOINT = 0xc0000251
    STATUS_BAD_SERVICE_ENTRYPOINT = 0xc0000252
    STATUS_LPC_REPLY_LOST = 0xc0000253
    STATUS_IP_ADDRESS_CONFLICT1 = 0xc0000254
    STATUS_IP_ADDRESS_CONFLICT2 = 0xc0000255
    STATUS_REGISTRY_QUOTA_LIMIT = 0xc0000256
    STATUS_PATH_NOT_COVERED = 0xc0000257
    STATUS_NO_CALLBACK_ACTIVE = 0xc0000258
    STATUS_LICENSE_QUOTA_EXCEEDED = 0xc0000259
    STATUS_PWD_TOO_SHORT = 0xc000025a
    STATUS_PWD_TOO_RECENT = 0xc000025b
    STATUS_PWD_HISTORY_CONFLICT = 0xc000025c
    STATUS_PLUGPLAY_NO_DEVICE = 0xc000025e
    STATUS_UNSUPPORTED_COMPRESSION = 0xc000025f
    STATUS_INVALID_HW_PROFILE = 0xc0000260
    STATUS_INVALID_PLUGPLAY_DEVICE_PATH = 0xc0000261
    STATUS_DRIVER_ORDINAL_NOT_FOUND = 0xc0000262
    STATUS_DRIVER_ENTRYPOINT_NOT_FOUND = 0xc0000263
    STATUS_RESOURCE_NOT_OWNED = 0xc0000264
    STATUS_TOO_MANY_LINKS = 0xc0000265
    STATUS_QUOTA_LIST_INCONSISTENT = 0xc0000266
    STATUS_FILE_IS_OFFLINE = 0xc0000267
    STATUS_EVALUATION_EXPIRATION = 0xc0000268
    STATUS_ILLEGAL_DLL_RELOCATION = 0xc0000269
    STATUS_LICENSE_VIOLATION = 0xc000026a
    STATUS_DLL_INIT_FAILED_LOGOFF = 0xc000026b
    STATUS_DRIVER_UNABLE_TO_LOAD = 0xc000026c
    STATUS_DFS_UNAVAILABLE = 0xc000026d
    STATUS_VOLUME_DISMOUNTED = 0xc000026e
    STATUS_WX86_INTERNAL_ERROR = 0xc000026f
    STATUS_WX86_FLOAT_STACK_CHECK = 0xc0000270
    STATUS_VALIDATE_CONTINUE = 0xc0000271
    STATUS_NO_MATCH = 0xc0000272
    STATUS_NO_MORE_MATCHES = 0xc0000273
    STATUS_NOT_A_REPARSE_POINT = 0xc0000275
    STATUS_IO_REPARSE_TAG_INVALID = 0xc0000276
    STATUS_IO_REPARSE_TAG_MISMATCH = 0xc0000277
    STATUS_IO_REPARSE_DATA_INVALID = 0xc0000278
    STATUS_IO_REPARSE_TAG_NOT_HANDLED = 0xc0000279
    STATUS_REPARSE_POINT_NOT_RESOLVED = 0xc0000280
    STATUS_DIRECTORY_IS_A_REPARSE_POINT = 0xc0000281
    STATUS_RANGE_LIST_CONFLICT = 0xc0000282
    STATUS_SOURCE_ELEMENT_EMPTY = 0xc0000283
    STATUS_DESTINATION_ELEMENT_FULL = 0xc0000284
    STATUS_ILLEGAL_ELEMENT_ADDRESS = 0xc0000285
    STATUS_MAGAZINE_NOT_PRESENT = 0xc0000286
    STATUS_REINITIALIZATION_NEEDED = 0xc0000287
    STATUS_ENCRYPTION_FAILED = 0xc000028a
    STATUS_DECRYPTION_FAILED = 0xc000028b
    STATUS_RANGE_NOT_FOUND = 0xc000028c
    STATUS_NO_RECOVERY_POLICY = 0xc000028d
    STATUS_NO_EFS = 0xc000028e
    STATUS_WRONG_EFS = 0xc000028f
    STATUS_NO_USER_KEYS = 0xc0000290
    STATUS_FILE_NOT_ENCRYPTED = 0xc0000291
    STATUS_NOT_EXPORT_FORMAT = 0xc0000292
    STATUS_FILE_ENCRYPTED = 0xc0000293
    STATUS_WMI_GUID_NOT_FOUND = 0xc0000295
    STATUS_WMI_INSTANCE_NOT_FOUND = 0xc0000296
    STATUS_WMI_ITEMID_NOT_FOUND = 0xc0000297
    STATUS_WMI_TRY_AGAIN = 0xc0000298
    STATUS_SHARED_POLICY = 0xc0000299
    STATUS_POLICY_OBJECT_NOT_FOUND = 0xc000029a
    STATUS_POLICY_ONLY_IN_DS = 0xc000029b
    STATUS_VOLUME_NOT_UPGRADED = 0xc000029c
    STATUS_REMOTE_STORAGE_NOT_ACTIVE = 0xc000029d
    STATUS_REMOTE_STORAGE_MEDIA_ERROR = 0xc000029e
    STATUS_NO_TRACKING_SERVICE = 0xc000029f
    STATUS_SERVER_SID_MISMATCH = 0xc00002a0
    STATUS_DS_NO_ATTRIBUTE_OR_VALUE = 0xc00002a1
    STATUS_DS_INVALID_ATTRIBUTE_SYNTAX = 0xc00002a2
    STATUS_DS_ATTRIBUTE_TYPE_UNDEFINED = 0xc00002a3
    STATUS_DS_ATTRIBUTE_OR_VALUE_EXISTS = 0xc00002a4
    STATUS_DS_BUSY = 0xc00002a5
    STATUS_DS_UNAVAILABLE = 0xc00002a6
    STATUS_DS_NO_RIDS_ALLOCATED = 0xc00002a7
    STATUS_DS_NO_MORE_RIDS = 0xc00002a8
    STATUS_DS_INCORRECT_ROLE_OWNER = 0xc00002a9
    STATUS_DS_RIDMGR_INIT_ERROR = 0xc00002aa
    STATUS_DS_OBJ_CLASS_VIOLATION = 0xc00002ab
    STATUS_DS_CANT_ON_NON_LEAF = 0xc00002ac
    STATUS_DS_CANT_ON_RDN = 0xc00002ad
    STATUS_DS_CANT_MOD_OBJ_CLASS = 0xc00002ae
    STATUS_DS_CROSS_DOM_MOVE_FAILED = 0xc00002af
    STATUS_DS_GC_NOT_AVAILABLE = 0xc00002b0
    STATUS_DIRECTORY_SERVICE_REQUIRED = 0xc00002b1
    STATUS_REPARSE_ATTRIBUTE_CONFLICT = 0xc00002b2
    STATUS_CANT_ENABLE_DENY_ONLY = 0xc00002b3
    STATUS_FLOAT_MULTIPLE_FAULTS = 0xc00002b4
    STATUS_FLOAT_MULTIPLE_TRAPS = 0xc00002b5
    STATUS_DEVICE_REMOVED = 0xc00002b6
    STATUS_JOURNAL_DELETE_IN_PROGRESS = 0xc00002b7
    STATUS_JOURNAL_NOT_ACTIVE = 0xc00002b8
    STATUS_NOINTERFACE = 0xc00002b9
    STATUS_DS_ADMIN_LIMIT_EXCEEDED = 0xc00002c1
    STATUS_DRIVER_FAILED_SLEEP = 0xc00002c2
    STATUS_MUTUAL_AUTHENTICATION_FAILED = 0xc00002c3
    STATUS_CORRUPT_SYSTEM_FILE = 0xc00002c4
    STATUS_DATATYPE_MISALIGNMENT_ERROR = 0xc00002c5
    STATUS_WMI_READ_ONLY = 0xc00002c6
    STATUS_WMI_SET_FAILURE = 0xc00002c7
    STATUS_COMMITMENT_MINIMUM = 0xc00002c8
    STATUS_REG_NAT_CONSUMPTION = 0xc00002c9
    STATUS_TRANSPORT_FULL = 0xc00002ca
    STATUS_DS_SAM_INIT_FAILURE = 0xc00002cb
    STATUS_ONLY_IF_CONNECTED = 0xc00002cc
    STATUS_DS_SENSITIVE_GROUP_VIOLATION = 0xc00002cd
    STATUS_PNP_RESTART_ENUMERATION = 0xc00002ce
    STATUS_JOURNAL_ENTRY_DELETED = 0xc00002cf
    STATUS_DS_CANT_MOD_PRIMARYGROUPID = 0xc00002d0
    STATUS_SYSTEM_IMAGE_BAD_SIGNATURE = 0xc00002d1
    STATUS_PNP_REBOOT_REQUIRED = 0xc00002d2
    STATUS_POWER_STATE_INVALID = 0xc00002d3
    STATUS_DS_INVALID_GROUP_TYPE = 0xc00002d4
    STATUS_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN = 0xc00002d5
    STATUS_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN = 0xc00002d6
    STATUS_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER = 0xc00002d7
    STATUS_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER = 0xc00002d8
    STATUS_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER = 0xc00002d9
    STATUS_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER = 0xc00002da
    STATUS_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER = 0xc00002db
    STATUS_DS_HAVE_PRIMARY_MEMBERS = 0xc00002dc
    STATUS_WMI_NOT_SUPPORTED = 0xc00002dd
    STATUS_INSUFFICIENT_POWER = 0xc00002de
    STATUS_SAM_NEED_BOOTKEY_PASSWORD = 0xc00002df
    STATUS_SAM_NEED_BOOTKEY_FLOPPY = 0xc00002e0
    STATUS_DS_CANT_START = 0xc00002e1
    STATUS_DS_INIT_FAILURE = 0xc00002e2
    STATUS_SAM_INIT_FAILURE = 0xc00002e3
    STATUS_DS_GC_REQUIRED = 0xc00002e4
    STATUS_DS_LOCAL_MEMBER_OF_LOCAL_ONLY = 0xc00002e5
    STATUS_DS_NO_FPO_IN_UNIVERSAL_GROUPS = 0xc00002e6
    STATUS_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED = 0xc00002e7
    STATUS_CURRENT_DOMAIN_NOT_ALLOWED = 0xc00002e9
    STATUS_CANNOT_MAKE = 0xc00002ea
    STATUS_SYSTEM_SHUTDOWN = 0xc00002eb
    STATUS_DS_INIT_FAILURE_CONSOLE = 0xc00002ec
    STATUS_DS_SAM_INIT_FAILURE_CONSOLE = 0xc00002ed
    STATUS_UNFINISHED_CONTEXT_DELETED = 0xc00002ee
    STATUS_NO_TGT_REPLY = 0xc00002ef
    STATUS_OBJECTID_NOT_FOUND = 0xc00002f0
    STATUS_NO_IP_ADDRESSES = 0xc00002f1
    STATUS_WRONG_CREDENTIAL_HANDLE = 0xc00002f2
    STATUS_CRYPTO_SYSTEM_INVALID = 0xc00002f3
    STATUS_MAX_REFERRALS_EXCEEDED = 0xc00002f4
    STATUS_MUST_BE_KDC = 0xc00002f5
    STATUS_STRONG_CRYPTO_NOT_SUPPORTED = 0xc00002f6
    STATUS_TOO_MANY_PRINCIPALS = 0xc00002f7
    STATUS_NO_PA_DATA = 0xc00002f8
    STATUS_PKINIT_NAME_MISMATCH = 0xc00002f9
    STATUS_SMARTCARD_LOGON_REQUIRED = 0xc00002fa
    STATUS_KDC_INVALID_REQUEST = 0xc00002fb
    STATUS_KDC_UNABLE_TO_REFER = 0xc00002fc
    STATUS_KDC_UNKNOWN_ETYPE = 0xc00002fd
    STATUS_SHUTDOWN_IN_PROGRESS = 0xc00002fe
    STATUS_SERVER_SHUTDOWN_IN_PROGRESS = 0xc00002ff
    STATUS_NOT_SUPPORTED_ON_SBS = 0xc0000300
    STATUS_WMI_GUID_DISCONNECTED = 0xc0000301
    STATUS_WMI_ALREADY_DISABLED = 0xc0000302
    STATUS_WMI_ALREADY_ENABLED = 0xc0000303
    STATUS_MFT_TOO_FRAGMENTED = 0xc0000304
    STATUS_COPY_PROTECTION_FAILURE = 0xc0000305
    STATUS_CSS_AUTHENTICATION_FAILURE = 0xc0000306
    STATUS_CSS_KEY_NOT_PRESENT = 0xc0000307
    STATUS_CSS_KEY_NOT_ESTABLISHED = 0xc0000308
    STATUS_CSS_SCRAMBLED_SECTOR = 0xc0000309
    STATUS_CSS_REGION_MISMATCH = 0xc000030a
    STATUS_CSS_RESETS_EXHAUSTED = 0xc000030b
    STATUS_PKINIT_FAILURE = 0xc0000320
    STATUS_SMARTCARD_SUBSYSTEM_FAILURE = 0xc0000321
    STATUS_NO_KERB_KEY = 0xc0000322
    STATUS_HOST_DOWN = 0xc0000350
    STATUS_UNSUPPORTED_PREAUTH = 0xc0000351
    STATUS_EFS_ALG_BLOB_TOO_BIG = 0xc0000352
    STATUS_PORT_NOT_SET = 0xc0000353
    STATUS_DEBUGGER_INACTIVE = 0xc0000354
    STATUS_DS_VERSION_CHECK_FAILURE = 0xc0000355
    STATUS_AUDITING_DISABLED = 0xc0000356
    STATUS_PRENT4_MACHINE_ACCOUNT = 0xc0000357
    STATUS_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER = 0xc0000358
    STATUS_INVALID_IMAGE_WIN_32 = 0xc0000359
    STATUS_INVALID_IMAGE_WIN_64 = 0xc000035a
    STATUS_BAD_BINDINGS = 0xc000035b
    STATUS_NETWORK_SESSION_EXPIRED = 0xc000035c
    STATUS_APPHELP_BLOCK = 0xc000035d
    STATUS_ALL_SIDS_FILTERED = 0xc000035e
    STATUS_NOT_SAFE_MODE_DRIVER = 0xc000035f
    STATUS_ACCESS_DISABLED_BY_POLICY_DEFAULT = 0xc0000361
    STATUS_ACCESS_DISABLED_BY_POLICY_PATH = 0xc0000362
    STATUS_ACCESS_DISABLED_BY_POLICY_PUBLISHER = 0xc0000363
    STATUS_ACCESS_DISABLED_BY_POLICY_OTHER = 0xc0000364
    STATUS_FAILED_DRIVER_ENTRY = 0xc0000365
    STATUS_DEVICE_ENUMERATION_ERROR = 0xc0000366
    STATUS_MOUNT_POINT_NOT_RESOLVED = 0xc0000368
    STATUS_INVALID_DEVICE_OBJECT_PARAMETER = 0xc0000369
    STATUS_MCA_OCCURED = 0xc000036a
    STATUS_DRIVER_BLOCKED_CRITICAL = 0xc000036b
    STATUS_DRIVER_BLOCKED = 0xc000036c
    STATUS_DRIVER_DATABASE_ERROR = 0xc000036d
    STATUS_SYSTEM_HIVE_TOO_LARGE = 0xc000036e
    STATUS_INVALID_IMPORT_OF_NON_DLL = 0xc000036f
    STATUS_NO_SECRETS = 0xc0000371
    STATUS_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY = 0xc0000372
    STATUS_FAILED_STACK_SWITCH = 0xc0000373
    STATUS_HEAP_CORRUPTION = 0xc0000374
    STATUS_SMARTCARD_WRONG_PIN = 0xc0000380
    STATUS_SMARTCARD_CARD_BLOCKED = 0xc0000381
    STATUS_SMARTCARD_CARD_NOT_AUTHENTICATED = 0xc0000382
    STATUS_SMARTCARD_NO_CARD = 0xc0000383
    STATUS_SMARTCARD_NO_KEY_CONTAINER = 0xc0000384
    STATUS_SMARTCARD_NO_CERTIFICATE = 0xc0000385
    STATUS_SMARTCARD_NO_KEYSET = 0xc0000386
    STATUS_SMARTCARD_IO_ERROR = 0xc0000387
    STATUS_DOWNGRADE_DETECTED = 0xc0000388
    STATUS_SMARTCARD_CERT_REVOKED = 0xc0000389
    STATUS_ISSUING_CA_UNTRUSTED = 0xc000038a
    STATUS_REVOCATION_OFFLINE_C = 0xc000038b
    STATUS_PKINIT_CLIENT_FAILURE = 0xc000038c
    STATUS_SMARTCARD_CERT_EXPIRED = 0xc000038d
    STATUS_DRIVER_FAILED_PRIOR_UNLOAD = 0xc000038e
    STATUS_SMARTCARD_SILENT_CONTEXT = 0xc000038f
    STATUS_PER_USER_TRUST_QUOTA_EXCEEDED = 0xc0000401
    STATUS_ALL_USER_TRUST_QUOTA_EXCEEDED = 0xc0000402
    STATUS_USER_DELETE_TRUST_QUOTA_EXCEEDED = 0xc0000403
    STATUS_DS_NAME_NOT_UNIQUE = 0xc0000404
    STATUS_DS_DUPLICATE_ID_FOUND = 0xc0000405
    STATUS_DS_GROUP_CONVERSION_ERROR = 0xc0000406
    STATUS_VOLSNAP_PREPARE_HIBERNATE = 0xc0000407
    STATUS_USER2USER_REQUIRED = 0xc0000408
    STATUS_STACK_BUFFER_OVERRUN = 0xc0000409
    STATUS_NO_S4U_PROT_SUPPORT = 0xc000040a
    STATUS_CROSSREALM_DELEGATION_FAILURE = 0xc000040b
    STATUS_REVOCATION_OFFLINE_KDC = 0xc000040c
    STATUS_ISSUING_CA_UNTRUSTED_KDC = 0xc000040d
    STATUS_KDC_CERT_EXPIRED = 0xc000040e
    STATUS_KDC_CERT_REVOKED = 0xc000040f
    STATUS_PARAMETER_QUOTA_EXCEEDED = 0xc0000410
    STATUS_HIBERNATION_FAILURE = 0xc0000411
    STATUS_DELAY_LOAD_FAILED = 0xc0000412
    STATUS_AUTHENTICATION_FIREWALL_FAILED = 0xc0000413
    STATUS_VDM_DISALLOWED = 0xc0000414
    STATUS_HUNG_DISPLAY_DRIVER_THREAD = 0xc0000415
    STATUS_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE = 0xc0000416
    STATUS_INVALID_CRUNTIME_PARAMETER = 0xc0000417
    STATUS_NTLM_BLOCKED = 0xc0000418
    STATUS_DS_SRC_SID_EXISTS_IN_FOREST = 0xc0000419
    STATUS_DS_DOMAIN_NAME_EXISTS_IN_FOREST = 0xc000041a
    STATUS_DS_FLAT_NAME_EXISTS_IN_FOREST = 0xc000041b
    STATUS_INVALID_USER_PRINCIPAL_NAME = 0xc000041c
    STATUS_ASSERTION_FAILURE = 0xc0000420
    STATUS_VERIFIER_STOP = 0xc0000421
    STATUS_CALLBACK_POP_STACK = 0xc0000423
    STATUS_INCOMPATIBLE_DRIVER_BLOCKED = 0xc0000424
    STATUS_HIVE_UNLOADED = 0xc0000425
    STATUS_COMPRESSION_DISABLED = 0xc0000426
    STATUS_FILE_SYSTEM_LIMITATION = 0xc0000427
    STATUS_INVALID_IMAGE_HASH = 0xc0000428
    STATUS_NOT_CAPABLE = 0xc0000429
    STATUS_REQUEST_OUT_OF_SEQUENCE = 0xc000042a
    STATUS_IMPLEMENTATION_LIMIT = 0xc000042b
    STATUS_ELEVATION_REQUIRED = 0xc000042c
    STATUS_NO_SECURITY_CONTEXT = 0xc000042d
    STATUS_PKU2U_CERT_FAILURE = 0xc000042e
    STATUS_BEYOND_VDL = 0xc0000432
    STATUS_ENCOUNTERED_WRITE_IN_PROGRESS = 0xc0000433
    STATUS_PTE_CHANGED = 0xc0000434
    STATUS_PURGE_FAILED = 0xc0000435
    STATUS_CRED_REQUIRES_CONFIRMATION = 0xc0000440
    STATUS_CS_ENCRYPTION_INVALID_SERVER_RESPONSE = 0xc0000441
    STATUS_CS_ENCRYPTION_UNSUPPORTED_SERVER = 0xc0000442
    STATUS_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE = 0xc0000443
    STATUS_CS_ENCRYPTION_NEW_ENCRYPTED_FILE = 0xc0000444
    STATUS_CS_ENCRYPTION_FILE_NOT_CSE = 0xc0000445
    STATUS_INVALID_LABEL = 0xc0000446
    STATUS_DRIVER_PROCESS_TERMINATED = 0xc0000450
    STATUS_AMBIGUOUS_SYSTEM_DEVICE = 0xc0000451
    STATUS_SYSTEM_DEVICE_NOT_FOUND = 0xc0000452
    STATUS_RESTART_BOOT_APPLICATION = 0xc0000453
    STATUS_INSUFFICIENT_NVRAM_RESOURCES = 0xc0000454
    STATUS_NO_RANGES_PROCESSED = 0xc0000460
    STATUS_DEVICE_FEATURE_NOT_SUPPORTED = 0xc0000463
    STATUS_DEVICE_UNREACHABLE = 0xc0000464
    STATUS_INVALID_TOKEN = 0xc0000465
    STATUS_SERVER_UNAVAILABLE = 0xc0000466
    STATUS_INVALID_TASK_NAME = 0xc0000500
    STATUS_INVALID_TASK_INDEX = 0xc0000501
    STATUS_THREAD_ALREADY_IN_TASK = 0xc0000502
    STATUS_CALLBACK_BYPASS = 0xc0000503
    STATUS_FAIL_FAST_EXCEPTION = 0xc0000602
    STATUS_IMAGE_CERT_REVOKED = 0xc0000603
    STATUS_PORT_CLOSED = 0xc0000700
    STATUS_MESSAGE_LOST = 0xc0000701
    STATUS_INVALID_MESSAGE = 0xc0000702
    STATUS_REQUEST_CANCELED = 0xc0000703
    STATUS_RECURSIVE_DISPATCH = 0xc0000704
    STATUS_LPC_RECEIVE_BUFFER_EXPECTED = 0xc0000705
    STATUS_LPC_INVALID_CONNECTION_USAGE = 0xc0000706
    STATUS_LPC_REQUESTS_NOT_ALLOWED = 0xc0000707
    STATUS_RESOURCE_IN_USE = 0xc0000708
    STATUS_HARDWARE_MEMORY_ERROR = 0xc0000709
    STATUS_THREADPOOL_HANDLE_EXCEPTION = 0xc000070a
    STATUS_THREADPOOL_SET_EVENT_ON_COMPLETION_FAILED = 0xc000070b
    STATUS_THREADPOOL_RELEASE_SEMAPHORE_ON_COMPLETION_FAILED = 0xc000070c
    STATUS_THREADPOOL_RELEASE_MUTEX_ON_COMPLETION_FAILED = 0xc000070d
    STATUS_THREADPOOL_FREE_LIBRARY_ON_COMPLETION_FAILED = 0xc000070e
    STATUS_THREADPOOL_RELEASED_DURING_OPERATION = 0xc000070f
    STATUS_CALLBACK_RETURNED_WHILE_IMPERSONATING = 0xc0000710
    STATUS_APC_RETURNED_WHILE_IMPERSONATING = 0xc0000711
    STATUS_PROCESS_IS_PROTECTED = 0xc0000712
    STATUS_MCA_EXCEPTION = 0xc0000713
    STATUS_CERTIFICATE_MAPPING_NOT_UNIQUE = 0xc0000714
    STATUS_SYMLINK_CLASS_DISABLED = 0xc0000715
    STATUS_INVALID_IDN_NORMALIZATION = 0xc0000716
    STATUS_NO_UNICODE_TRANSLATION = 0xc0000717
    STATUS_ALREADY_REGISTERED = 0xc0000718
    STATUS_CONTEXT_MISMATCH = 0xc0000719
    STATUS_PORT_ALREADY_HAS_COMPLETION_LIST = 0xc000071a
    STATUS_CALLBACK_RETURNED_THREAD_PRIORITY = 0xc000071b
    STATUS_INVALID_THREAD = 0xc000071c
    STATUS_CALLBACK_RETURNED_TRANSACTION = 0xc000071d
    STATUS_CALLBACK_RETURNED_LDR_LOCK = 0xc000071e
    STATUS_CALLBACK_RETURNED_LANG = 0xc000071f
    STATUS_CALLBACK_RETURNED_PRI_BACK = 0xc0000720
    STATUS_DISK_REPAIR_DISABLED = 0xc0000800
    STATUS_DS_DOMAIN_RENAME_IN_PROGRESS = 0xc0000801
    STATUS_DISK_QUOTA_EXCEEDED = 0xc0000802
    STATUS_CONTENT_BLOCKED = 0xc0000804
    STATUS_BAD_CLUSTERS = 0xc0000805
    STATUS_VOLUME_DIRTY = 0xc0000806
    STATUS_FILE_CHECKED_OUT = 0xc0000901
    STATUS_CHECKOUT_REQUIRED = 0xc0000902
    STATUS_BAD_FILE_TYPE = 0xc0000903
    STATUS_FILE_TOO_LARGE = 0xc0000904
    STATUS_FORMS_AUTH_REQUIRED = 0xc0000905
    STATUS_VIRUS_INFECTED = 0xc0000906
    STATUS_VIRUS_DELETED = 0xc0000907
    STATUS_BAD_MCFG_TABLE = 0xc0000908
    STATUS_CANNOT_BREAK_OPLOCK = 0xc0000909
    STATUS_WOW_ASSERTION = 0xc0009898
    STATUS_INVALID_SIGNATURE = 0xc000a000
    STATUS_HMAC_NOT_SUPPORTED = 0xc000a001
    STATUS_IPSEC_QUEUE_OVERFLOW = 0xc000a010
    STATUS_ND_QUEUE_OVERFLOW = 0xc000a011
    STATUS_HOPLIMIT_EXCEEDED = 0xc000a012
    STATUS_PROTOCOL_NOT_SUPPORTED = 0xc000a013
    STATUS_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED = 0xc000a080
    STATUS_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR = 0xc000a081
    STATUS_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR = 0xc000a082
    STATUS_XML_PARSE_ERROR = 0xc000a083
    STATUS_XMLDSIG_ERROR = 0xc000a084
    STATUS_WRONG_COMPARTMENT = 0xc000a085
    STATUS_AUTHIP_FAILURE = 0xc000a086
    STATUS_DS_OID_MAPPED_GROUP_CANT_HAVE_MEMBERS = 0xc000a087
    STATUS_DS_OID_NOT_FOUND = 0xc000a088
    STATUS_HASH_NOT_SUPPORTED = 0xc000a100
    STATUS_HASH_NOT_PRESENT = 0xc000a101
    STATUS_OFFLOAD_READ_FLT_NOT_SUPPORTED = 0xc000a2a1
    STATUS_OFFLOAD_WRITE_FLT_NOT_SUPPORTED = 0xc000a2a2
    STATUS_OFFLOAD_READ_FILE_NOT_SUPPORTED = 0xc000a2a3
    STATUS_OFFLOAD_WRITE_FILE_NOT_SUPPORTED = 0xc000a2a4
    DBG_NO_STATE_CHANGE = 0xc0010001
    DBG_APP_NOT_IDLE = 0xc0010002
    RPC_NT_INVALID_STRING_BINDING = 0xc0020001
    RPC_NT_WRONG_KIND_OF_BINDING = 0xc0020002
    RPC_NT_INVALID_BINDING = 0xc0020003
    RPC_NT_PROTSEQ_NOT_SUPPORTED = 0xc0020004
    RPC_NT_INVALID_RPC_PROTSEQ = 0xc0020005
    RPC_NT_INVALID_STRING_UUID = 0xc0020006
    RPC_NT_INVALID_ENDPOINT_FORMAT = 0xc0020007
    RPC_NT_INVALID_NET_ADDR = 0xc0020008
    RPC_NT_NO_ENDPOINT_FOUND = 0xc0020009
    RPC_NT_INVALID_TIMEOUT = 0xc002000a
    RPC_NT_OBJECT_NOT_FOUND = 0xc002000b
    RPC_NT_ALREADY_REGISTERED = 0xc002000c
    RPC_NT_TYPE_ALREADY_REGISTERED = 0xc002000d
    RPC_NT_ALREADY_LISTENING = 0xc002000e
    RPC_NT_NO_PROTSEQS_REGISTERED = 0xc002000f
    RPC_NT_NOT_LISTENING = 0xc0020010
    RPC_NT_UNKNOWN_MGR_TYPE = 0xc0020011
    RPC_NT_UNKNOWN_IF = 0xc0020012
    RPC_NT_NO_BINDINGS = 0xc0020013
    RPC_NT_NO_PROTSEQS = 0xc0020014
    RPC_NT_CANT_CREATE_ENDPOINT = 0xc0020015
    RPC_NT_OUT_OF_RESOURCES = 0xc0020016
    RPC_NT_SERVER_UNAVAILABLE = 0xc0020017
    RPC_NT_SERVER_TOO_BUSY = 0xc0020018
    RPC_NT_INVALID_NETWORK_OPTIONS = 0xc0020019
    RPC_NT_NO_CALL_ACTIVE = 0xc002001a
    RPC_NT_CALL_FAILED = 0xc002001b
    RPC_NT_CALL_FAILED_DNE = 0xc002001c
    RPC_NT_PROTOCOL_ERROR = 0xc002001d
    RPC_NT_UNSUPPORTED_TRANS_SYN = 0xc002001f
    RPC_NT_UNSUPPORTED_TYPE = 0xc0020021
    RPC_NT_INVALID_TAG = 0xc0020022
    RPC_NT_INVALID_BOUND = 0xc0020023
    RPC_NT_NO_ENTRY_NAME = 0xc0020024
    RPC_NT_INVALID_NAME_SYNTAX = 0xc0020025
    RPC_NT_UNSUPPORTED_NAME_SYNTAX = 0xc0020026
    RPC_NT_UUID_NO_ADDRESS = 0xc0020028
    RPC_NT_DUPLICATE_ENDPOINT = 0xc0020029
    RPC_NT_UNKNOWN_AUTHN_TYPE = 0xc002002a
    RPC_NT_MAX_CALLS_TOO_SMALL = 0xc002002b
    RPC_NT_STRING_TOO_LONG = 0xc002002c
    RPC_NT_PROTSEQ_NOT_FOUND = 0xc002002d
    RPC_NT_PROCNUM_OUT_OF_RANGE = 0xc002002e
    RPC_NT_BINDING_HAS_NO_AUTH = 0xc002002f
    RPC_NT_UNKNOWN_AUTHN_SERVICE = 0xc0020030
    RPC_NT_UNKNOWN_AUTHN_LEVEL = 0xc0020031
    RPC_NT_INVALID_AUTH_IDENTITY = 0xc0020032
    RPC_NT_UNKNOWN_AUTHZ_SERVICE = 0xc0020033
    EPT_NT_INVALID_ENTRY = 0xc0020034
    EPT_NT_CANT_PERFORM_OP = 0xc0020035
    EPT_NT_NOT_REGISTERED = 0xc0020036
    RPC_NT_NOTHING_TO_EXPORT = 0xc0020037
    RPC_NT_INCOMPLETE_NAME = 0xc0020038
    RPC_NT_INVALID_VERS_OPTION = 0xc0020039
    RPC_NT_NO_MORE_MEMBERS = 0xc002003a
    RPC_NT_NOT_ALL_OBJS_UNEXPORTED = 0xc002003b
    RPC_NT_INTERFACE_NOT_FOUND = 0xc002003c
    RPC_NT_ENTRY_ALREADY_EXISTS = 0xc002003d
    RPC_NT_ENTRY_NOT_FOUND = 0xc002003e
    RPC_NT_NAME_SERVICE_UNAVAILABLE = 0xc002003f
    RPC_NT_INVALID_NAF_ID = 0xc0020040
    RPC_NT_CANNOT_SUPPORT = 0xc0020041
    RPC_NT_NO_CONTEXT_AVAILABLE = 0xc0020042
    RPC_NT_INTERNAL_ERROR = 0xc0020043
    RPC_NT_ZERO_DIVIDE = 0xc0020044
    RPC_NT_ADDRESS_ERROR = 0xc0020045
    RPC_NT_FP_DIV_ZERO = 0xc0020046
    RPC_NT_FP_UNDERFLOW = 0xc0020047
    RPC_NT_FP_OVERFLOW = 0xc0020048
    RPC_NT_CALL_IN_PROGRESS = 0xc0020049
    RPC_NT_NO_MORE_BINDINGS = 0xc002004a
    RPC_NT_GROUP_MEMBER_NOT_FOUND = 0xc002004b
    EPT_NT_CANT_CREATE = 0xc002004c
    RPC_NT_INVALID_OBJECT = 0xc002004d
    RPC_NT_NO_INTERFACES = 0xc002004f
    RPC_NT_CALL_CANCELLED = 0xc0020050
    RPC_NT_BINDING_INCOMPLETE = 0xc0020051
    RPC_NT_COMM_FAILURE = 0xc0020052
    RPC_NT_UNSUPPORTED_AUTHN_LEVEL = 0xc0020053
    RPC_NT_NO_PRINC_NAME = 0xc0020054
    RPC_NT_NOT_RPC_ERROR = 0xc0020055
    RPC_NT_SEC_PKG_ERROR = 0xc0020057
    RPC_NT_NOT_CANCELLED = 0xc0020058
    RPC_NT_INVALID_ASYNC_HANDLE = 0xc0020062
    RPC_NT_INVALID_ASYNC_CALL = 0xc0020063
    RPC_NT_PROXY_ACCESS_DENIED = 0xc0020064
    RPC_NT_NO_MORE_ENTRIES = 0xc0030001
    RPC_NT_SS_CHAR_TRANS_OPEN_FAIL = 0xc0030002
    RPC_NT_SS_CHAR_TRANS_SHORT_FILE = 0xc0030003
    RPC_NT_SS_IN_NULL_CONTEXT = 0xc0030004
    RPC_NT_SS_CONTEXT_MISMATCH = 0xc0030005
    RPC_NT_SS_CONTEXT_DAMAGED = 0xc0030006
    RPC_NT_SS_HANDLES_MISMATCH = 0xc0030007
    RPC_NT_SS_CANNOT_GET_CALL_HANDLE = 0xc0030008
    RPC_NT_NULL_REF_POINTER = 0xc0030009
    RPC_NT_ENUM_VALUE_OUT_OF_RANGE = 0xc003000a
    RPC_NT_BYTE_COUNT_TOO_SMALL = 0xc003000b
    RPC_NT_BAD_STUB_DATA = 0xc003000c
    RPC_NT_INVALID_ES_ACTION = 0xc0030059
    RPC_NT_WRONG_ES_VERSION = 0xc003005a
    RPC_NT_WRONG_STUB_VERSION = 0xc003005b
    RPC_NT_INVALID_PIPE_OBJECT = 0xc003005c
    RPC_NT_INVALID_PIPE_OPERATION = 0xc003005d
    RPC_NT_WRONG_PIPE_VERSION = 0xc003005e
    RPC_NT_PIPE_CLOSED = 0xc003005f
    RPC_NT_PIPE_DISCIPLINE_ERROR = 0xc0030060
    RPC_NT_PIPE_EMPTY = 0xc0030061
    STATUS_PNP_BAD_MPS_TABLE = 0xc0040035
    STATUS_PNP_TRANSLATION_FAILED = 0xc0040036
    STATUS_PNP_IRQ_TRANSLATION_FAILED = 0xc0040037
    STATUS_PNP_INVALID_ID = 0xc0040038
    STATUS_IO_REISSUE_AS_CACHED = 0xc0040039
    STATUS_CTX_WINSTATION_NAME_INVALID = 0xc00a0001
    STATUS_CTX_INVALID_PD = 0xc00a0002
    STATUS_CTX_PD_NOT_FOUND = 0xc00a0003
    STATUS_CTX_CLOSE_PENDING = 0xc00a0006
    STATUS_CTX_NO_OUTBUF = 0xc00a0007
    STATUS_CTX_MODEM_INF_NOT_FOUND = 0xc00a0008
    STATUS_CTX_INVALID_MODEMNAME = 0xc00a0009
    STATUS_CTX_RESPONSE_ERROR = 0xc00a000a
    STATUS_CTX_MODEM_RESPONSE_TIMEOUT = 0xc00a000b
    STATUS_CTX_MODEM_RESPONSE_NO_CARRIER = 0xc00a000c
    STATUS_CTX_MODEM_RESPONSE_NO_DIALTONE = 0xc00a000d
    STATUS_CTX_MODEM_RESPONSE_BUSY = 0xc00a000e
    STATUS_CTX_MODEM_RESPONSE_VOICE = 0xc00a000f
    STATUS_CTX_TD_ERROR = 0xc00a0010
    STATUS_CTX_LICENSE_CLIENT_INVALID = 0xc00a0012
    STATUS_CTX_LICENSE_NOT_AVAILABLE = 0xc00a0013
    STATUS_CTX_LICENSE_EXPIRED = 0xc00a0014
    STATUS_CTX_WINSTATION_NOT_FOUND = 0xc00a0015
    STATUS_CTX_WINSTATION_NAME_COLLISION = 0xc00a0016
    STATUS_CTX_WINSTATION_BUSY = 0xc00a0017
    STATUS_CTX_BAD_VIDEO_MODE = 0xc00a0018
    STATUS_CTX_GRAPHICS_INVALID = 0xc00a0022
    STATUS_CTX_NOT_CONSOLE = 0xc00a0024
    STATUS_CTX_CLIENT_QUERY_TIMEOUT = 0xc00a0026
    STATUS_CTX_CONSOLE_DISCONNECT = 0xc00a0027
    STATUS_CTX_CONSOLE_CONNECT = 0xc00a0028
    STATUS_CTX_SHADOW_DENIED = 0xc00a002a
    STATUS_CTX_WINSTATION_ACCESS_DENIED = 0xc00a002b
    STATUS_CTX_INVALID_WD = 0xc00a002e
    STATUS_CTX_WD_NOT_FOUND = 0xc00a002f
    STATUS_CTX_SHADOW_INVALID = 0xc00a0030
    STATUS_CTX_SHADOW_DISABLED = 0xc00a0031
    STATUS_RDP_PROTOCOL_ERROR = 0xc00a0032
    STATUS_CTX_CLIENT_LICENSE_NOT_SET = 0xc00a0033
    STATUS_CTX_CLIENT_LICENSE_IN_USE = 0xc00a0034
    STATUS_CTX_SHADOW_ENDED_BY_MODE_CHANGE = 0xc00a0035
    STATUS_CTX_SHADOW_NOT_RUNNING = 0xc00a0036
    STATUS_CTX_LOGON_DISABLED = 0xc00a0037
    STATUS_CTX_SECURITY_LAYER_ERROR = 0xc00a0038
    STATUS_TS_INCOMPATIBLE_SESSIONS = 0xc00a0039
    STATUS_MUI_FILE_NOT_FOUND = 0xc00b0001
    STATUS_MUI_INVALID_FILE = 0xc00b0002
    STATUS_MUI_INVALID_RC_CONFIG = 0xc00b0003
    STATUS_MUI_INVALID_LOCALE_NAME = 0xc00b0004
    STATUS_MUI_INVALID_ULTIMATEFALLBACK_NAME = 0xc00b0005
    STATUS_MUI_FILE_NOT_LOADED = 0xc00b0006
    STATUS_RESOURCE_ENUM_USER_STOP = 0xc00b0007
    STATUS_CLUSTER_INVALID_NODE = 0xc0130001
    STATUS_CLUSTER_NODE_EXISTS = 0xc0130002
    STATUS_CLUSTER_JOIN_IN_PROGRESS = 0xc0130003
    STATUS_CLUSTER_NODE_NOT_FOUND = 0xc0130004
    STATUS_CLUSTER_LOCAL_NODE_NOT_FOUND = 0xc0130005
    STATUS_CLUSTER_NETWORK_EXISTS = 0xc0130006
    STATUS_CLUSTER_NETWORK_NOT_FOUND = 0xc0130007
    STATUS_CLUSTER_NETINTERFACE_EXISTS = 0xc0130008
    STATUS_CLUSTER_NETINTERFACE_NOT_FOUND = 0xc0130009
    STATUS_CLUSTER_INVALID_REQUEST = 0xc013000a
    STATUS_CLUSTER_INVALID_NETWORK_PROVIDER = 0xc013000b
    STATUS_CLUSTER_NODE_DOWN = 0xc013000c
    STATUS_CLUSTER_NODE_UNREACHABLE = 0xc013000d
    STATUS_CLUSTER_NODE_NOT_MEMBER = 0xc013000e
    STATUS_CLUSTER_JOIN_NOT_IN_PROGRESS = 0xc013000f
    STATUS_CLUSTER_INVALID_NETWORK = 0xc0130010
    STATUS_CLUSTER_NO_NET_ADAPTERS = 0xc0130011
    STATUS_CLUSTER_NODE_UP = 0xc0130012
    STATUS_CLUSTER_NODE_PAUSED = 0xc0130013
    STATUS_CLUSTER_NODE_NOT_PAUSED = 0xc0130014
    STATUS_CLUSTER_NO_SECURITY_CONTEXT = 0xc0130015
    STATUS_CLUSTER_NETWORK_NOT_INTERNAL = 0xc0130016
    STATUS_CLUSTER_POISONED = 0xc0130017
    STATUS_ACPI_INVALID_OPCODE = 0xc0140001
    STATUS_ACPI_STACK_OVERFLOW = 0xc0140002
    STATUS_ACPI_ASSERT_FAILED = 0xc0140003
    STATUS_ACPI_INVALID_INDEX = 0xc0140004
    STATUS_ACPI_INVALID_ARGUMENT = 0xc0140005
    STATUS_ACPI_FATAL = 0xc0140006
    STATUS_ACPI_INVALID_SUPERNAME = 0xc0140007
    STATUS_ACPI_INVALID_ARGTYPE = 0xc0140008
    STATUS_ACPI_INVALID_OBJTYPE = 0xc0140009
    STATUS_ACPI_INVALID_TARGETTYPE = 0xc014000a
    STATUS_ACPI_INCORRECT_ARGUMENT_COUNT = 0xc014000b
    STATUS_ACPI_ADDRESS_NOT_MAPPED = 0xc014000c
    STATUS_ACPI_INVALID_EVENTTYPE = 0xc014000d
    STATUS_ACPI_HANDLER_COLLISION = 0xc014000e
    STATUS_ACPI_INVALID_DATA = 0xc014000f
    STATUS_ACPI_INVALID_REGION = 0xc0140010
    STATUS_ACPI_INVALID_ACCESS_SIZE = 0xc0140011
    STATUS_ACPI_ACQUIRE_GLOBAL_LOCK = 0xc0140012
    STATUS_ACPI_ALREADY_INITIALIZED = 0xc0140013
    STATUS_ACPI_NOT_INITIALIZED = 0xc0140014
    STATUS_ACPI_INVALID_MUTEX_LEVEL = 0xc0140015
    STATUS_ACPI_MUTEX_NOT_OWNED = 0xc0140016
    STATUS_ACPI_MUTEX_NOT_OWNER = 0xc0140017
    STATUS_ACPI_RS_ACCESS = 0xc0140018
    STATUS_ACPI_INVALID_TABLE = 0xc0140019
    STATUS_ACPI_REG_HANDLER_FAILED = 0xc0140020
    STATUS_ACPI_POWER_REQUEST_FAILED = 0xc0140021
    STATUS_SXS_SECTION_NOT_FOUND = 0xc0150001
    STATUS_SXS_CANT_GEN_ACTCTX = 0xc0150002
    STATUS_SXS_INVALID_ACTCTXDATA_FORMAT = 0xc0150003
    STATUS_SXS_ASSEMBLY_NOT_FOUND = 0xc0150004
    STATUS_SXS_MANIFEST_FORMAT_ERROR = 0xc0150005
    STATUS_SXS_MANIFEST_PARSE_ERROR = 0xc0150006
    STATUS_SXS_ACTIVATION_CONTEXT_DISABLED = 0xc0150007
    STATUS_SXS_KEY_NOT_FOUND = 0xc0150008
    STATUS_SXS_VERSION_CONFLICT = 0xc0150009
    STATUS_SXS_WRONG_SECTION_TYPE = 0xc015000a
    STATUS_SXS_THREAD_QUERIES_DISABLED = 0xc015000b
    STATUS_SXS_ASSEMBLY_MISSING = 0xc015000c
    STATUS_SXS_PROCESS_DEFAULT_ALREADY_SET = 0xc015000e
    STATUS_SXS_EARLY_DEACTIVATION = 0xc015000f
    STATUS_SXS_INVALID_DEACTIVATION = 0xc0150010
    STATUS_SXS_MULTIPLE_DEACTIVATION = 0xc0150011
    STATUS_SXS_SYSTEM_DEFAULT_ACTIVATION_CONTEXT_EMPTY = 0xc0150012
    STATUS_SXS_PROCESS_TERMINATION_REQUESTED = 0xc0150013
    STATUS_SXS_CORRUPT_ACTIVATION_STACK = 0xc0150014
    STATUS_SXS_CORRUPTION = 0xc0150015
    STATUS_SXS_INVALID_IDENTITY_ATTRIBUTE_VALUE = 0xc0150016
    STATUS_SXS_INVALID_IDENTITY_ATTRIBUTE_NAME = 0xc0150017
    STATUS_SXS_IDENTITY_DUPLICATE_ATTRIBUTE = 0xc0150018
    STATUS_SXS_IDENTITY_PARSE_ERROR = 0xc0150019
    STATUS_SXS_COMPONENT_STORE_CORRUPT = 0xc015001a
    STATUS_SXS_FILE_HASH_MISMATCH = 0xc015001b
    STATUS_SXS_MANIFEST_IDENTITY_SAME_BUT_CONTENTS_DIFFERENT = 0xc015001c
    STATUS_SXS_IDENTITIES_DIFFERENT = 0xc015001d
    STATUS_SXS_ASSEMBLY_IS_NOT_A_DEPLOYMENT = 0xc015001e
    STATUS_SXS_FILE_NOT_PART_OF_ASSEMBLY = 0xc015001f
    STATUS_ADVANCED_INSTALLER_FAILED = 0xc0150020
    STATUS_XML_ENCODING_MISMATCH = 0xc0150021
    STATUS_SXS_MANIFEST_TOO_BIG = 0xc0150022
    STATUS_SXS_SETTING_NOT_REGISTERED = 0xc0150023
    STATUS_SXS_TRANSACTION_CLOSURE_INCOMPLETE = 0xc0150024
    STATUS_SMI_PRIMITIVE_INSTALLER_FAILED = 0xc0150025
    STATUS_GENERIC_COMMAND_FAILED = 0xc0150026
    STATUS_SXS_FILE_HASH_MISSING = 0xc0150027
    STATUS_TRANSACTIONAL_CONFLICT = 0xc0190001
    STATUS_INVALID_TRANSACTION = 0xc0190002
    STATUS_TRANSACTION_NOT_ACTIVE = 0xc0190003
    STATUS_TM_INITIALIZATION_FAILED = 0xc0190004
    STATUS_RM_NOT_ACTIVE = 0xc0190005
    STATUS_RM_METADATA_CORRUPT = 0xc0190006
    STATUS_TRANSACTION_NOT_JOINED = 0xc0190007
    STATUS_DIRECTORY_NOT_RM = 0xc0190008
    STATUS_TRANSACTIONS_UNSUPPORTED_REMOTE = 0xc019000a
    STATUS_LOG_RESIZE_INVALID_SIZE = 0xc019000b
    STATUS_REMOTE_FILE_VERSION_MISMATCH = 0xc019000c
    STATUS_CRM_PROTOCOL_ALREADY_EXISTS = 0xc019000f
    STATUS_TRANSACTION_PROPAGATION_FAILED = 0xc0190010
    STATUS_CRM_PROTOCOL_NOT_FOUND = 0xc0190011
    STATUS_TRANSACTION_SUPERIOR_EXISTS = 0xc0190012
    STATUS_TRANSACTION_REQUEST_NOT_VALID = 0xc0190013
    STATUS_TRANSACTION_NOT_REQUESTED = 0xc0190014
    STATUS_TRANSACTION_ALREADY_ABORTED = 0xc0190015
    STATUS_TRANSACTION_ALREADY_COMMITTED = 0xc0190016
    STATUS_TRANSACTION_INVALID_MARSHALL_BUFFER = 0xc0190017
    STATUS_CURRENT_TRANSACTION_NOT_VALID = 0xc0190018
    STATUS_LOG_GROWTH_FAILED = 0xc0190019
    STATUS_OBJECT_NO_LONGER_EXISTS = 0xc0190021
    STATUS_STREAM_MINIVERSION_NOT_FOUND = 0xc0190022
    STATUS_STREAM_MINIVERSION_NOT_VALID = 0xc0190023
    STATUS_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION = 0xc0190024
    STATUS_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT = 0xc0190025
    STATUS_CANT_CREATE_MORE_STREAM_MINIVERSIONS = 0xc0190026
    STATUS_HANDLE_NO_LONGER_VALID = 0xc0190028
    STATUS_LOG_CORRUPTION_DETECTED = 0xc0190030
    STATUS_RM_DISCONNECTED = 0xc0190032
    STATUS_ENLISTMENT_NOT_SUPERIOR = 0xc0190033
    STATUS_FILE_IDENTITY_NOT_PERSISTENT = 0xc0190036
    STATUS_CANT_BREAK_TRANSACTIONAL_DEPENDENCY = 0xc0190037
    STATUS_CANT_CROSS_RM_BOUNDARY = 0xc0190038
    STATUS_TXF_DIR_NOT_EMPTY = 0xc0190039
    STATUS_INDOUBT_TRANSACTIONS_EXIST = 0xc019003a
    STATUS_TM_VOLATILE = 0xc019003b
    STATUS_ROLLBACK_TIMER_EXPIRED = 0xc019003c
    STATUS_TXF_ATTRIBUTE_CORRUPT = 0xc019003d
    STATUS_EFS_NOT_ALLOWED_IN_TRANSACTION = 0xc019003e
    STATUS_TRANSACTIONAL_OPEN_NOT_ALLOWED = 0xc019003f
    STATUS_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE = 0xc0190040
    STATUS_TRANSACTION_REQUIRED_PROMOTION = 0xc0190043
    STATUS_CANNOT_EXECUTE_FILE_IN_TRANSACTION = 0xc0190044
    STATUS_TRANSACTIONS_NOT_FROZEN = 0xc0190045
    STATUS_TRANSACTION_FREEZE_IN_PROGRESS = 0xc0190046
    STATUS_NOT_SNAPSHOT_VOLUME = 0xc0190047
    STATUS_NO_SAVEPOINT_WITH_OPEN_FILES = 0xc0190048
    STATUS_SPARSE_NOT_ALLOWED_IN_TRANSACTION = 0xc0190049
    STATUS_TM_IDENTITY_MISMATCH = 0xc019004a
    STATUS_FLOATED_SECTION = 0xc019004b
    STATUS_CANNOT_ACCEPT_TRANSACTED_WORK = 0xc019004c
    STATUS_CANNOT_ABORT_TRANSACTIONS = 0xc019004d
    STATUS_TRANSACTION_NOT_FOUND = 0xc019004e
    STATUS_RESOURCEMANAGER_NOT_FOUND = 0xc019004f
    STATUS_ENLISTMENT_NOT_FOUND = 0xc0190050
    STATUS_TRANSACTIONMANAGER_NOT_FOUND = 0xc0190051
    STATUS_TRANSACTIONMANAGER_NOT_ONLINE = 0xc0190052
    STATUS_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION = 0xc0190053
    STATUS_TRANSACTION_NOT_ROOT = 0xc0190054
    STATUS_TRANSACTION_OBJECT_EXPIRED = 0xc0190055
    STATUS_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION = 0xc0190056
    STATUS_TRANSACTION_RESPONSE_NOT_ENLISTED = 0xc0190057
    STATUS_TRANSACTION_RECORD_TOO_LONG = 0xc0190058
    STATUS_NO_LINK_TRACKING_IN_TRANSACTION = 0xc0190059
    STATUS_OPERATION_NOT_SUPPORTED_IN_TRANSACTION = 0xc019005a
    STATUS_TRANSACTION_INTEGRITY_VIOLATED = 0xc019005b
    STATUS_EXPIRED_HANDLE = 0xc0190060
    STATUS_TRANSACTION_NOT_ENLISTED = 0xc0190061
    STATUS_LOG_SECTOR_INVALID = 0xc01a0001
    STATUS_LOG_SECTOR_PARITY_INVALID = 0xc01a0002
    STATUS_LOG_SECTOR_REMAPPED = 0xc01a0003
    STATUS_LOG_BLOCK_INCOMPLETE = 0xc01a0004
    STATUS_LOG_INVALID_RANGE = 0xc01a0005
    STATUS_LOG_BLOCKS_EXHAUSTED = 0xc01a0006
    STATUS_LOG_READ_CONTEXT_INVALID = 0xc01a0007
    STATUS_LOG_RESTART_INVALID = 0xc01a0008
    STATUS_LOG_BLOCK_VERSION = 0xc01a0009
    STATUS_LOG_BLOCK_INVALID = 0xc01a000a
    STATUS_LOG_READ_MODE_INVALID = 0xc01a000b
    STATUS_LOG_METADATA_CORRUPT = 0xc01a000d
    STATUS_LOG_METADATA_INVALID = 0xc01a000e
    STATUS_LOG_METADATA_INCONSISTENT = 0xc01a000f
    STATUS_LOG_RESERVATION_INVALID = 0xc01a0010
    STATUS_LOG_CANT_DELETE = 0xc01a0011
    STATUS_LOG_CONTAINER_LIMIT_EXCEEDED = 0xc01a0012
    STATUS_LOG_START_OF_LOG = 0xc01a0013
    STATUS_LOG_POLICY_ALREADY_INSTALLED = 0xc01a0014
    STATUS_LOG_POLICY_NOT_INSTALLED = 0xc01a0015
    STATUS_LOG_POLICY_INVALID = 0xc01a0016
    STATUS_LOG_POLICY_CONFLICT = 0xc01a0017
    STATUS_LOG_PINNED_ARCHIVE_TAIL = 0xc01a0018
    STATUS_LOG_RECORD_NONEXISTENT = 0xc01a0019
    STATUS_LOG_RECORDS_RESERVED_INVALID = 0xc01a001a
    STATUS_LOG_SPACE_RESERVED_INVALID = 0xc01a001b
    STATUS_LOG_TAIL_INVALID = 0xc01a001c
    STATUS_LOG_FULL = 0xc01a001d
    STATUS_LOG_MULTIPLEXED = 0xc01a001e
    STATUS_LOG_DEDICATED = 0xc01a001f
    STATUS_LOG_ARCHIVE_NOT_IN_PROGRESS = 0xc01a0020
    STATUS_LOG_ARCHIVE_IN_PROGRESS = 0xc01a0021
    STATUS_LOG_EPHEMERAL = 0xc01a0022
    STATUS_LOG_NOT_ENOUGH_CONTAINERS = 0xc01a0023
    STATUS_LOG_CLIENT_ALREADY_REGISTERED = 0xc01a0024
    STATUS_LOG_CLIENT_NOT_REGISTERED = 0xc01a0025
    STATUS_LOG_FULL_HANDLER_IN_PROGRESS = 0xc01a0026
    STATUS_LOG_CONTAINER_READ_FAILED = 0xc01a0027
    STATUS_LOG_CONTAINER_WRITE_FAILED = 0xc01a0028
    STATUS_LOG_CONTAINER_OPEN_FAILED = 0xc01a0029
    STATUS_LOG_CONTAINER_STATE_INVALID = 0xc01a002a
    STATUS_LOG_STATE_INVALID = 0xc01a002b
    STATUS_LOG_PINNED = 0xc01a002c
    STATUS_LOG_METADATA_FLUSH_FAILED = 0xc01a002d
    STATUS_LOG_INCONSISTENT_SECURITY = 0xc01a002e
    STATUS_LOG_APPENDED_FLUSH_FAILED = 0xc01a002f
    STATUS_LOG_PINNED_RESERVATION = 0xc01a0030
    STATUS_VIDEO_HUNG_DISPLAY_DRIVER_THREAD = 0xc01b00ea
    STATUS_FLT_NO_HANDLER_DEFINED = 0xc01c0001
    STATUS_FLT_CONTEXT_ALREADY_DEFINED = 0xc01c0002
    STATUS_FLT_INVALID_ASYNCHRONOUS_REQUEST = 0xc01c0003
    STATUS_FLT_DISALLOW_FAST_IO = 0xc01c0004
    STATUS_FLT_INVALID_NAME_REQUEST = 0xc01c0005
    STATUS_FLT_NOT_SAFE_TO_POST_OPERATION = 0xc01c0006
    STATUS_FLT_NOT_INITIALIZED = 0xc01c0007
    STATUS_FLT_FILTER_NOT_READY = 0xc01c0008
    STATUS_FLT_POST_OPERATION_CLEANUP = 0xc01c0009
    STATUS_FLT_INTERNAL_ERROR = 0xc01c000a
    STATUS_FLT_DELETING_OBJECT = 0xc01c000b
    STATUS_FLT_MUST_BE_NONPAGED_POOL = 0xc01c000c
    STATUS_FLT_DUPLICATE_ENTRY = 0xc01c000d
    STATUS_FLT_CBDQ_DISABLED = 0xc01c000e
    STATUS_FLT_DO_NOT_ATTACH = 0xc01c000f
    STATUS_FLT_DO_NOT_DETACH = 0xc01c0010
    STATUS_FLT_INSTANCE_ALTITUDE_COLLISION = 0xc01c0011
    STATUS_FLT_INSTANCE_NAME_COLLISION = 0xc01c0012
    STATUS_FLT_FILTER_NOT_FOUND = 0xc01c0013
    STATUS_FLT_VOLUME_NOT_FOUND = 0xc01c0014
    STATUS_FLT_INSTANCE_NOT_FOUND = 0xc01c0015
    STATUS_FLT_CONTEXT_ALLOCATION_NOT_FOUND = 0xc01c0016
    STATUS_FLT_INVALID_CONTEXT_REGISTRATION = 0xc01c0017
    STATUS_FLT_NAME_CACHE_MISS = 0xc01c0018
    STATUS_FLT_NO_DEVICE_OBJECT = 0xc01c0019
    STATUS_FLT_VOLUME_ALREADY_MOUNTED = 0xc01c001a
    STATUS_FLT_ALREADY_ENLISTED = 0xc01c001b
    STATUS_FLT_CONTEXT_ALREADY_LINKED = 0xc01c001c
    STATUS_FLT_NO_WAITER_FOR_REPLY = 0xc01c0020
    STATUS_MONITOR_NO_DESCRIPTOR = 0xc01d0001
    STATUS_MONITOR_UNKNOWN_DESCRIPTOR_FORMAT = 0xc01d0002
    STATUS_MONITOR_INVALID_DESCRIPTOR_CHECKSUM = 0xc01d0003
    STATUS_MONITOR_INVALID_STANDARD_TIMING_BLOCK = 0xc01d0004
    STATUS_MONITOR_WMI_DATABLOCK_REGISTRATION_FAILED = 0xc01d0005
    STATUS_MONITOR_INVALID_SERIAL_NUMBER_MONDSC_BLOCK = 0xc01d0006
    STATUS_MONITOR_INVALID_USER_FRIENDLY_MONDSC_BLOCK = 0xc01d0007
    STATUS_MONITOR_NO_MORE_DESCRIPTOR_DATA = 0xc01d0008
    STATUS_MONITOR_INVALID_DETAILED_TIMING_BLOCK = 0xc01d0009
    STATUS_MONITOR_INVALID_MANUFACTURE_DATE = 0xc01d000a
    STATUS_GRAPHICS_NOT_EXCLUSIVE_MODE_OWNER = 0xc01e0000
    STATUS_GRAPHICS_INSUFFICIENT_DMA_BUFFER = 0xc01e0001
    STATUS_GRAPHICS_INVALID_DISPLAY_ADAPTER = 0xc01e0002
    STATUS_GRAPHICS_ADAPTER_WAS_RESET = 0xc01e0003
    STATUS_GRAPHICS_INVALID_DRIVER_MODEL = 0xc01e0004
    STATUS_GRAPHICS_PRESENT_MODE_CHANGED = 0xc01e0005
    STATUS_GRAPHICS_PRESENT_OCCLUDED = 0xc01e0006
    STATUS_GRAPHICS_PRESENT_DENIED = 0xc01e0007
    STATUS_GRAPHICS_CANNOTCOLORCONVERT = 0xc01e0008
    STATUS_GRAPHICS_PRESENT_REDIRECTION_DISABLED = 0xc01e000b
    STATUS_GRAPHICS_PRESENT_UNOCCLUDED = 0xc01e000c
    STATUS_GRAPHICS_NO_VIDEO_MEMORY = 0xc01e0100
    STATUS_GRAPHICS_CANT_LOCK_MEMORY = 0xc01e0101
    STATUS_GRAPHICS_ALLOCATION_BUSY = 0xc01e0102
    STATUS_GRAPHICS_TOO_MANY_REFERENCES = 0xc01e0103
    STATUS_GRAPHICS_TRY_AGAIN_LATER = 0xc01e0104
    STATUS_GRAPHICS_TRY_AGAIN_NOW = 0xc01e0105
    STATUS_GRAPHICS_ALLOCATION_INVALID = 0xc01e0106
    STATUS_GRAPHICS_UNSWIZZLING_APERTURE_UNAVAILABLE = 0xc01e0107
    STATUS_GRAPHICS_UNSWIZZLING_APERTURE_UNSUPPORTED = 0xc01e0108
    STATUS_GRAPHICS_CANT_EVICT_PINNED_ALLOCATION = 0xc01e0109
    STATUS_GRAPHICS_INVALID_ALLOCATION_USAGE = 0xc01e0110
    STATUS_GRAPHICS_CANT_RENDER_LOCKED_ALLOCATION = 0xc01e0111
    STATUS_GRAPHICS_ALLOCATION_CLOSED = 0xc01e0112
    STATUS_GRAPHICS_INVALID_ALLOCATION_INSTANCE = 0xc01e0113
    STATUS_GRAPHICS_INVALID_ALLOCATION_HANDLE = 0xc01e0114
    STATUS_GRAPHICS_WRONG_ALLOCATION_DEVICE = 0xc01e0115
    STATUS_GRAPHICS_ALLOCATION_CONTENT_LOST = 0xc01e0116
    STATUS_GRAPHICS_GPU_EXCEPTION_ON_DEVICE = 0xc01e0200
    STATUS_GRAPHICS_INVALID_VIDPN_TOPOLOGY = 0xc01e0300
    STATUS_GRAPHICS_VIDPN_TOPOLOGY_NOT_SUPPORTED = 0xc01e0301
    STATUS_GRAPHICS_VIDPN_TOPOLOGY_CURRENTLY_NOT_SUPPORTED = 0xc01e0302
    STATUS_GRAPHICS_INVALID_VIDPN = 0xc01e0303
    STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE = 0xc01e0304
    STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET = 0xc01e0305
    STATUS_GRAPHICS_VIDPN_MODALITY_NOT_SUPPORTED = 0xc01e0306
    STATUS_GRAPHICS_INVALID_VIDPN_SOURCEMODESET = 0xc01e0308
    STATUS_GRAPHICS_INVALID_VIDPN_TARGETMODESET = 0xc01e0309
    STATUS_GRAPHICS_INVALID_FREQUENCY = 0xc01e030a
    STATUS_GRAPHICS_INVALID_ACTIVE_REGION = 0xc01e030b
    STATUS_GRAPHICS_INVALID_TOTAL_REGION = 0xc01e030c
    STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_SOURCE_MODE = 0xc01e0310
    STATUS_GRAPHICS_INVALID_VIDEO_PRESENT_TARGET_MODE = 0xc01e0311
    STATUS_GRAPHICS_PINNED_MODE_MUST_REMAIN_IN_SET = 0xc01e0312
    STATUS_GRAPHICS_PATH_ALREADY_IN_TOPOLOGY = 0xc01e0313
    STATUS_GRAPHICS_MODE_ALREADY_IN_MODESET = 0xc01e0314
    STATUS_GRAPHICS_INVALID_VIDEOPRESENTSOURCESET = 0xc01e0315
    STATUS_GRAPHICS_INVALID_VIDEOPRESENTTARGETSET = 0xc01e0316
    STATUS_GRAPHICS_SOURCE_ALREADY_IN_SET = 0xc01e0317
    STATUS_GRAPHICS_TARGET_ALREADY_IN_SET = 0xc01e0318
    STATUS_GRAPHICS_INVALID_VIDPN_PRESENT_PATH = 0xc01e0319
    STATUS_GRAPHICS_NO_RECOMMENDED_VIDPN_TOPOLOGY = 0xc01e031a
    STATUS_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGESET = 0xc01e031b
    STATUS_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE = 0xc01e031c
    STATUS_GRAPHICS_FREQUENCYRANGE_NOT_IN_SET = 0xc01e031d
    STATUS_GRAPHICS_FREQUENCYRANGE_ALREADY_IN_SET = 0xc01e031f
    STATUS_GRAPHICS_STALE_MODESET = 0xc01e0320
    STATUS_GRAPHICS_INVALID_MONITOR_SOURCEMODESET = 0xc01e0321
    STATUS_GRAPHICS_INVALID_MONITOR_SOURCE_MODE = 0xc01e0322
    STATUS_GRAPHICS_NO_RECOMMENDED_FUNCTIONAL_VIDPN = 0xc01e0323
    STATUS_GRAPHICS_MODE_ID_MUST_BE_UNIQUE = 0xc01e0324
    STATUS_GRAPHICS_EMPTY_ADAPTER_MONITOR_MODE_SUPPORT_INTERSECTION = 0xc01e0325
    STATUS_GRAPHICS_VIDEO_PRESENT_TARGETS_LESS_THAN_SOURCES = 0xc01e0326
    STATUS_GRAPHICS_PATH_NOT_IN_TOPOLOGY = 0xc01e0327
    STATUS_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_SOURCE = 0xc01e0328
    STATUS_GRAPHICS_ADAPTER_MUST_HAVE_AT_LEAST_ONE_TARGET = 0xc01e0329
    STATUS_GRAPHICS_INVALID_MONITORDESCRIPTORSET = 0xc01e032a
    STATUS_GRAPHICS_INVALID_MONITORDESCRIPTOR = 0xc01e032b
    STATUS_GRAPHICS_MONITORDESCRIPTOR_NOT_IN_SET = 0xc01e032c
    STATUS_GRAPHICS_MONITORDESCRIPTOR_ALREADY_IN_SET = 0xc01e032d
    STATUS_GRAPHICS_MONITORDESCRIPTOR_ID_MUST_BE_UNIQUE = 0xc01e032e
    STATUS_GRAPHICS_INVALID_VIDPN_TARGET_SUBSET_TYPE = 0xc01e032f
    STATUS_GRAPHICS_RESOURCES_NOT_RELATED = 0xc01e0330
    STATUS_GRAPHICS_SOURCE_ID_MUST_BE_UNIQUE = 0xc01e0331
    STATUS_GRAPHICS_TARGET_ID_MUST_BE_UNIQUE = 0xc01e0332
    STATUS_GRAPHICS_NO_AVAILABLE_VIDPN_TARGET = 0xc01e0333
    STATUS_GRAPHICS_MONITOR_COULD_NOT_BE_ASSOCIATED_WITH_ADAPTER = 0xc01e0334
    STATUS_GRAPHICS_NO_VIDPNMGR = 0xc01e0335
    STATUS_GRAPHICS_NO_ACTIVE_VIDPN = 0xc01e0336
    STATUS_GRAPHICS_STALE_VIDPN_TOPOLOGY = 0xc01e0337
    STATUS_GRAPHICS_MONITOR_NOT_CONNECTED = 0xc01e0338
    STATUS_GRAPHICS_SOURCE_NOT_IN_TOPOLOGY = 0xc01e0339
    STATUS_GRAPHICS_INVALID_PRIMARYSURFACE_SIZE = 0xc01e033a
    STATUS_GRAPHICS_INVALID_VISIBLEREGION_SIZE = 0xc01e033b
    STATUS_GRAPHICS_INVALID_STRIDE = 0xc01e033c
    STATUS_GRAPHICS_INVALID_PIXELFORMAT = 0xc01e033d
    STATUS_GRAPHICS_INVALID_COLORBASIS = 0xc01e033e
    STATUS_GRAPHICS_INVALID_PIXELVALUEACCESSMODE = 0xc01e033f
    STATUS_GRAPHICS_TARGET_NOT_IN_TOPOLOGY = 0xc01e0340
    STATUS_GRAPHICS_NO_DISPLAY_MODE_MANAGEMENT_SUPPORT = 0xc01e0341
    STATUS_GRAPHICS_VIDPN_SOURCE_IN_USE = 0xc01e0342
    STATUS_GRAPHICS_CANT_ACCESS_ACTIVE_VIDPN = 0xc01e0343
    STATUS_GRAPHICS_INVALID_PATH_IMPORTANCE_ORDINAL = 0xc01e0344
    STATUS_GRAPHICS_INVALID_PATH_CONTENT_GEOMETRY_TRANSFORMATION = 0xc01e0345
    STATUS_GRAPHICS_PATH_CONTENT_GEOMETRY_TRANSFORMATION_NOT_SUPPORTED = 0xc01e0346
    STATUS_GRAPHICS_INVALID_GAMMA_RAMP = 0xc01e0347
    STATUS_GRAPHICS_GAMMA_RAMP_NOT_SUPPORTED = 0xc01e0348
    STATUS_GRAPHICS_MULTISAMPLING_NOT_SUPPORTED = 0xc01e0349
    STATUS_GRAPHICS_MODE_NOT_IN_MODESET = 0xc01e034a
    STATUS_GRAPHICS_INVALID_VIDPN_TOPOLOGY_RECOMMENDATION_REASON = 0xc01e034d
    STATUS_GRAPHICS_INVALID_PATH_CONTENT_TYPE = 0xc01e034e
    STATUS_GRAPHICS_INVALID_COPYPROTECTION_TYPE = 0xc01e034f
    STATUS_GRAPHICS_UNASSIGNED_MODESET_ALREADY_EXISTS = 0xc01e0350
    STATUS_GRAPHICS_INVALID_SCANLINE_ORDERING = 0xc01e0352
    STATUS_GRAPHICS_TOPOLOGY_CHANGES_NOT_ALLOWED = 0xc01e0353
    STATUS_GRAPHICS_NO_AVAILABLE_IMPORTANCE_ORDINALS = 0xc01e0354
    STATUS_GRAPHICS_INCOMPATIBLE_PRIVATE_FORMAT = 0xc01e0355
    STATUS_GRAPHICS_INVALID_MODE_PRUNING_ALGORITHM = 0xc01e0356
    STATUS_GRAPHICS_INVALID_MONITOR_CAPABILITY_ORIGIN = 0xc01e0357
    STATUS_GRAPHICS_INVALID_MONITOR_FREQUENCYRANGE_CONSTRAINT = 0xc01e0358
    STATUS_GRAPHICS_MAX_NUM_PATHS_REACHED = 0xc01e0359
    STATUS_GRAPHICS_CANCEL_VIDPN_TOPOLOGY_AUGMENTATION = 0xc01e035a
    STATUS_GRAPHICS_INVALID_CLIENT_TYPE = 0xc01e035b
    STATUS_GRAPHICS_CLIENTVIDPN_NOT_SET = 0xc01e035c
    STATUS_GRAPHICS_SPECIFIED_CHILD_ALREADY_CONNECTED = 0xc01e0400
    STATUS_GRAPHICS_CHILD_DESCRIPTOR_NOT_SUPPORTED = 0xc01e0401
    STATUS_GRAPHICS_NOT_A_LINKED_ADAPTER = 0xc01e0430
    STATUS_GRAPHICS_LEADLINK_NOT_ENUMERATED = 0xc01e0431
    STATUS_GRAPHICS_CHAINLINKS_NOT_ENUMERATED = 0xc01e0432
    STATUS_GRAPHICS_ADAPTER_CHAIN_NOT_READY = 0xc01e0433
    STATUS_GRAPHICS_CHAINLINKS_NOT_STARTED = 0xc01e0434
    STATUS_GRAPHICS_CHAINLINKS_NOT_POWERED_ON = 0xc01e0435
    STATUS_GRAPHICS_INCONSISTENT_DEVICE_LINK_STATE = 0xc01e0436
    STATUS_GRAPHICS_NOT_POST_DEVICE_DRIVER = 0xc01e0438
    STATUS_GRAPHICS_ADAPTER_ACCESS_NOT_EXCLUDED = 0xc01e043b
    STATUS_GRAPHICS_OPM_NOT_SUPPORTED = 0xc01e0500
    STATUS_GRAPHICS_COPP_NOT_SUPPORTED = 0xc01e0501
    STATUS_GRAPHICS_UAB_NOT_SUPPORTED = 0xc01e0502
    STATUS_GRAPHICS_OPM_INVALID_ENCRYPTED_PARAMETERS = 0xc01e0503
    STATUS_GRAPHICS_OPM_PARAMETER_ARRAY_TOO_SMALL = 0xc01e0504
    STATUS_GRAPHICS_OPM_NO_PROTECTED_OUTPUTS_EXIST = 0xc01e0505
    STATUS_GRAPHICS_PVP_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME = 0xc01e0506
    STATUS_GRAPHICS_PVP_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP = 0xc01e0507
    STATUS_GRAPHICS_PVP_MIRRORING_DEVICES_NOT_SUPPORTED = 0xc01e0508
    STATUS_GRAPHICS_OPM_INVALID_POINTER = 0xc01e050a
    STATUS_GRAPHICS_OPM_INTERNAL_ERROR = 0xc01e050b
    STATUS_GRAPHICS_OPM_INVALID_HANDLE = 0xc01e050c
    STATUS_GRAPHICS_PVP_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE = 0xc01e050d
    STATUS_GRAPHICS_PVP_INVALID_CERTIFICATE_LENGTH = 0xc01e050e
    STATUS_GRAPHICS_OPM_SPANNING_MODE_ENABLED = 0xc01e050f
    STATUS_GRAPHICS_OPM_THEATER_MODE_ENABLED = 0xc01e0510
    STATUS_GRAPHICS_PVP_HFS_FAILED = 0xc01e0511
    STATUS_GRAPHICS_OPM_INVALID_SRM = 0xc01e0512
    STATUS_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_HDCP = 0xc01e0513
    STATUS_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_ACP = 0xc01e0514
    STATUS_GRAPHICS_OPM_OUTPUT_DOES_NOT_SUPPORT_CGMSA = 0xc01e0515
    STATUS_GRAPHICS_OPM_HDCP_SRM_NEVER_SET = 0xc01e0516
    STATUS_GRAPHICS_OPM_RESOLUTION_TOO_HIGH = 0xc01e0517
    STATUS_GRAPHICS_OPM_ALL_HDCP_HARDWARE_ALREADY_IN_USE = 0xc01e0518
    STATUS_GRAPHICS_OPM_PROTECTED_OUTPUT_NO_LONGER_EXISTS = 0xc01e051a
    STATUS_GRAPHICS_OPM_SESSION_TYPE_CHANGE_IN_PROGRESS = 0xc01e051b
    STATUS_GRAPHICS_OPM_PROTECTED_OUTPUT_DOES_NOT_HAVE_COPP_SEMANTICS = 0xc01e051c
    STATUS_GRAPHICS_OPM_INVALID_INFORMATION_REQUEST = 0xc01e051d
    STATUS_GRAPHICS_OPM_DRIVER_INTERNAL_ERROR = 0xc01e051e
    STATUS_GRAPHICS_OPM_PROTECTED_OUTPUT_DOES_NOT_HAVE_OPM_SEMANTICS = 0xc01e051f
    STATUS_GRAPHICS_OPM_SIGNALING_NOT_SUPPORTED = 0xc01e0520
    STATUS_GRAPHICS_OPM_INVALID_CONFIGURATION_REQUEST = 0xc01e0521
    STATUS_GRAPHICS_I2C_NOT_SUPPORTED = 0xc01e0580
    STATUS_GRAPHICS_I2C_DEVICE_DOES_NOT_EXIST = 0xc01e0581
    STATUS_GRAPHICS_I2C_ERROR_TRANSMITTING_DATA = 0xc01e0582
    STATUS_GRAPHICS_I2C_ERROR_RECEIVING_DATA = 0xc01e0583
    STATUS_GRAPHICS_DDCCI_VCP_NOT_SUPPORTED = 0xc01e0584
    STATUS_GRAPHICS_DDCCI_INVALID_DATA = 0xc01e0585
    STATUS_GRAPHICS_DDCCI_MONITOR_RETURNED_INVALID_TIMING_STATUS_BYTE = 0xc01e0586
    STATUS_GRAPHICS_DDCCI_INVALID_CAPABILITIES_STRING = 0xc01e0587
    STATUS_GRAPHICS_MCA_INTERNAL_ERROR = 0xc01e0588
    STATUS_GRAPHICS_DDCCI_INVALID_MESSAGE_COMMAND = 0xc01e0589
    STATUS_GRAPHICS_DDCCI_INVALID_MESSAGE_LENGTH = 0xc01e058a
    STATUS_GRAPHICS_DDCCI_INVALID_MESSAGE_CHECKSUM = 0xc01e058b
    STATUS_GRAPHICS_INVALID_PHYSICAL_MONITOR_HANDLE = 0xc01e058c
    STATUS_GRAPHICS_MONITOR_NO_LONGER_EXISTS = 0xc01e058d
    STATUS_GRAPHICS_ONLY_CONSOLE_SESSION_SUPPORTED = 0xc01e05e0
    STATUS_GRAPHICS_NO_DISPLAY_DEVICE_CORRESPONDS_TO_NAME = 0xc01e05e1
    STATUS_GRAPHICS_DISPLAY_DEVICE_NOT_ATTACHED_TO_DESKTOP = 0xc01e05e2
    STATUS_GRAPHICS_MIRRORING_DEVICES_NOT_SUPPORTED = 0xc01e05e3
    STATUS_GRAPHICS_INVALID_POINTER = 0xc01e05e4
    STATUS_GRAPHICS_NO_MONITORS_CORRESPOND_TO_DISPLAY_DEVICE = 0xc01e05e5
    STATUS_GRAPHICS_PARAMETER_ARRAY_TOO_SMALL = 0xc01e05e6
    STATUS_GRAPHICS_INTERNAL_ERROR = 0xc01e05e7
    STATUS_GRAPHICS_SESSION_TYPE_CHANGE_IN_PROGRESS = 0xc01e05e8
    STATUS_FVE_LOCKED_VOLUME = 0xc0210000
    STATUS_FVE_NOT_ENCRYPTED = 0xc0210001
    STATUS_FVE_BAD_INFORMATION = 0xc0210002
    STATUS_FVE_TOO_SMALL = 0xc0210003
    STATUS_FVE_FAILED_WRONG_FS = 0xc0210004
    STATUS_FVE_FAILED_BAD_FS = 0xc0210005
    STATUS_FVE_FS_NOT_EXTENDED = 0xc0210006
    STATUS_FVE_FS_MOUNTED = 0xc0210007
    STATUS_FVE_NO_LICENSE = 0xc0210008
    STATUS_FVE_ACTION_NOT_ALLOWED = 0xc0210009
    STATUS_FVE_BAD_DATA = 0xc021000a
    STATUS_FVE_VOLUME_NOT_BOUND = 0xc021000b
    STATUS_FVE_NOT_DATA_VOLUME = 0xc021000c
    STATUS_FVE_CONV_READ_ERROR = 0xc021000d
    STATUS_FVE_CONV_WRITE_ERROR = 0xc021000e
    STATUS_FVE_OVERLAPPED_UPDATE = 0xc021000f
    STATUS_FVE_FAILED_SECTOR_SIZE = 0xc0210010
    STATUS_FVE_FAILED_AUTHENTICATION = 0xc0210011
    STATUS_FVE_NOT_OS_VOLUME = 0xc0210012
    STATUS_FVE_KEYFILE_NOT_FOUND = 0xc0210013
    STATUS_FVE_KEYFILE_INVALID = 0xc0210014
    STATUS_FVE_KEYFILE_NO_VMK = 0xc0210015
    STATUS_FVE_TPM_DISABLED = 0xc0210016
    STATUS_FVE_TPM_SRK_AUTH_NOT_ZERO = 0xc0210017
    STATUS_FVE_TPM_INVALID_PCR = 0xc0210018
    STATUS_FVE_TPM_NO_VMK = 0xc0210019
    STATUS_FVE_PIN_INVALID = 0xc021001a
    STATUS_FVE_AUTH_INVALID_APPLICATION = 0xc021001b
    STATUS_FVE_AUTH_INVALID_CONFIG = 0xc021001c
    STATUS_FVE_DEBUGGER_ENABLED = 0xc021001d
    STATUS_FVE_DRY_RUN_FAILED = 0xc021001e
    STATUS_FVE_BAD_METADATA_POINTER = 0xc021001f
    STATUS_FVE_OLD_METADATA_COPY = 0xc0210020
    STATUS_FVE_REBOOT_REQUIRED = 0xc0210021
    STATUS_FVE_RAW_ACCESS = 0xc0210022
    STATUS_FVE_RAW_BLOCKED = 0xc0210023
    STATUS_FVE_NO_FEATURE_LICENSE = 0xc0210026
    STATUS_FVE_POLICY_USER_DISABLE_RDV_NOT_ALLOWED = 0xc0210027
    STATUS_FVE_CONV_RECOVERY_FAILED = 0xc0210028
    STATUS_FVE_VIRTUALIZED_SPACE_TOO_BIG = 0xc0210029
    STATUS_FVE_VOLUME_TOO_SMALL = 0xc0210030
    STATUS_FWP_CALLOUT_NOT_FOUND = 0xc0220001
    STATUS_FWP_CONDITION_NOT_FOUND = 0xc0220002
    STATUS_FWP_FILTER_NOT_FOUND = 0xc0220003
    STATUS_FWP_LAYER_NOT_FOUND = 0xc0220004
    STATUS_FWP_PROVIDER_NOT_FOUND = 0xc0220005
    STATUS_FWP_PROVIDER_CONTEXT_NOT_FOUND = 0xc0220006
    STATUS_FWP_SUBLAYER_NOT_FOUND = 0xc0220007
    STATUS_FWP_NOT_FOUND = 0xc0220008
    STATUS_FWP_ALREADY_EXISTS = 0xc0220009
    STATUS_FWP_IN_USE = 0xc022000a
    STATUS_FWP_DYNAMIC_SESSION_IN_PROGRESS = 0xc022000b
    STATUS_FWP_WRONG_SESSION = 0xc022000c
    STATUS_FWP_NO_TXN_IN_PROGRESS = 0xc022000d
    STATUS_FWP_TXN_IN_PROGRESS = 0xc022000e
    STATUS_FWP_TXN_ABORTED = 0xc022000f
    STATUS_FWP_SESSION_ABORTED = 0xc0220010
    STATUS_FWP_INCOMPATIBLE_TXN = 0xc0220011
    STATUS_FWP_TIMEOUT = 0xc0220012
    STATUS_FWP_NET_EVENTS_DISABLED = 0xc0220013
    STATUS_FWP_INCOMPATIBLE_LAYER = 0xc0220014
    STATUS_FWP_KM_CLIENTS_ONLY = 0xc0220015
    STATUS_FWP_LIFETIME_MISMATCH = 0xc0220016
    STATUS_FWP_BUILTIN_OBJECT = 0xc0220017
    STATUS_FWP_TOO_MANY_BOOTTIME_FILTERS = 0xc0220018
    STATUS_FWP_TOO_MANY_CALLOUTS = 0xc0220018
    STATUS_FWP_NOTIFICATION_DROPPED = 0xc0220019
    STATUS_FWP_TRAFFIC_MISMATCH = 0xc022001a
    STATUS_FWP_INCOMPATIBLE_SA_STATE = 0xc022001b
    STATUS_FWP_NULL_POINTER = 0xc022001c
    STATUS_FWP_INVALID_ENUMERATOR = 0xc022001d
    STATUS_FWP_INVALID_FLAGS = 0xc022001e
    STATUS_FWP_INVALID_NET_MASK = 0xc022001f
    STATUS_FWP_INVALID_RANGE = 0xc0220020
    STATUS_FWP_INVALID_INTERVAL = 0xc0220021
    STATUS_FWP_ZERO_LENGTH_ARRAY = 0xc0220022
    STATUS_FWP_NULL_DISPLAY_NAME = 0xc0220023
    STATUS_FWP_INVALID_ACTION_TYPE = 0xc0220024
    STATUS_FWP_INVALID_WEIGHT = 0xc0220025
    STATUS_FWP_MATCH_TYPE_MISMATCH = 0xc0220026
    STATUS_FWP_TYPE_MISMATCH = 0xc0220027
    STATUS_FWP_OUT_OF_BOUNDS = 0xc0220028
    STATUS_FWP_RESERVED = 0xc0220029
    STATUS_FWP_DUPLICATE_CONDITION = 0xc022002a
    STATUS_FWP_DUPLICATE_KEYMOD = 0xc022002b
    STATUS_FWP_ACTION_INCOMPATIBLE_WITH_LAYER = 0xc022002c
    STATUS_FWP_ACTION_INCOMPATIBLE_WITH_SUBLAYER = 0xc022002d
    STATUS_FWP_CONTEXT_INCOMPATIBLE_WITH_LAYER = 0xc022002e
    STATUS_FWP_CONTEXT_INCOMPATIBLE_WITH_CALLOUT = 0xc022002f
    STATUS_FWP_INCOMPATIBLE_AUTH_METHOD = 0xc0220030
    STATUS_FWP_INCOMPATIBLE_DH_GROUP = 0xc0220031
    STATUS_FWP_EM_NOT_SUPPORTED = 0xc0220032
    STATUS_FWP_NEVER_MATCH = 0xc0220033
    STATUS_FWP_PROVIDER_CONTEXT_MISMATCH = 0xc0220034
    STATUS_FWP_INVALID_PARAMETER = 0xc0220035
    STATUS_FWP_TOO_MANY_SUBLAYERS = 0xc0220036
    STATUS_FWP_CALLOUT_NOTIFICATION_FAILED = 0xc0220037
    STATUS_FWP_INCOMPATIBLE_AUTH_CONFIG = 0xc0220038
    STATUS_FWP_INCOMPATIBLE_CIPHER_CONFIG = 0xc0220039
    STATUS_FWP_DUPLICATE_AUTH_METHOD = 0xc022003c
    STATUS_FWP_TCPIP_NOT_READY = 0xc0220100
    STATUS_FWP_INJECT_HANDLE_CLOSING = 0xc0220101
    STATUS_FWP_INJECT_HANDLE_STALE = 0xc0220102
    STATUS_FWP_CANNOT_PEND = 0xc0220103
    STATUS_NDIS_CLOSING = 0xc0230002
    STATUS_NDIS_BAD_VERSION = 0xc0230004
    STATUS_NDIS_BAD_CHARACTERISTICS = 0xc0230005
    STATUS_NDIS_ADAPTER_NOT_FOUND = 0xc0230006
    STATUS_NDIS_OPEN_FAILED = 0xc0230007
    STATUS_NDIS_DEVICE_FAILED = 0xc0230008
    STATUS_NDIS_MULTICAST_FULL = 0xc0230009
    STATUS_NDIS_MULTICAST_EXISTS = 0xc023000a
    STATUS_NDIS_MULTICAST_NOT_FOUND = 0xc023000b
    STATUS_NDIS_REQUEST_ABORTED = 0xc023000c
    STATUS_NDIS_RESET_IN_PROGRESS = 0xc023000d
    STATUS_NDIS_INVALID_PACKET = 0xc023000f
    STATUS_NDIS_INVALID_DEVICE_REQUEST = 0xc0230010
    STATUS_NDIS_ADAPTER_NOT_READY = 0xc0230011
    STATUS_NDIS_INVALID_LENGTH = 0xc0230014
    STATUS_NDIS_INVALID_DATA = 0xc0230015
    STATUS_NDIS_BUFFER_TOO_SHORT = 0xc0230016
    STATUS_NDIS_INVALID_OID = 0xc0230017
    STATUS_NDIS_ADAPTER_REMOVED = 0xc0230018
    STATUS_NDIS_UNSUPPORTED_MEDIA = 0xc0230019
    STATUS_NDIS_GROUP_ADDRESS_IN_USE = 0xc023001a
    STATUS_NDIS_FILE_NOT_FOUND = 0xc023001b
    STATUS_NDIS_ERROR_READING_FILE = 0xc023001c
    STATUS_NDIS_ALREADY_MAPPED = 0xc023001d
    STATUS_NDIS_RESOURCE_CONFLICT = 0xc023001e
    STATUS_NDIS_MEDIA_DISCONNECTED = 0xc023001f
    STATUS_NDIS_INVALID_ADDRESS = 0xc0230022
    STATUS_NDIS_PAUSED = 0xc023002a
    STATUS_NDIS_INTERFACE_NOT_FOUND = 0xc023002b
    STATUS_NDIS_UNSUPPORTED_REVISION = 0xc023002c
    STATUS_NDIS_INVALID_PORT = 0xc023002d
    STATUS_NDIS_INVALID_PORT_STATE = 0xc023002e
    STATUS_NDIS_LOW_POWER_STATE = 0xc023002f
    STATUS_NDIS_NOT_SUPPORTED = 0xc02300bb
    STATUS_NDIS_OFFLOAD_POLICY = 0xc023100f
    STATUS_NDIS_OFFLOAD_CONNECTION_REJECTED = 0xc0231012
    STATUS_NDIS_OFFLOAD_PATH_REJECTED = 0xc0231013
    STATUS_NDIS_DOT11_AUTO_CONFIG_ENABLED = 0xc0232000
    STATUS_NDIS_DOT11_MEDIA_IN_USE = 0xc0232001
    STATUS_NDIS_DOT11_POWER_STATE_INVALID = 0xc0232002
    STATUS_NDIS_PM_WOL_PATTERN_LIST_FULL = 0xc0232003
    STATUS_NDIS_PM_PROTOCOL_OFFLOAD_LIST_FULL = 0xc0232004
    STATUS_IPSEC_BAD_SPI = 0xc0360001
    STATUS_IPSEC_SA_LIFETIME_EXPIRED = 0xc0360002
    STATUS_IPSEC_WRONG_SA = 0xc0360003
    STATUS_IPSEC_REPLAY_CHECK_FAILED = 0xc0360004
    STATUS_IPSEC_INVALID_PACKET = 0xc0360005
    STATUS_IPSEC_INTEGRITY_CHECK_FAILED = 0xc0360006
    STATUS_IPSEC_CLEAR_TEXT_DROP = 0xc0360007
    STATUS_IPSEC_AUTH_FIREWALL_DROP = 0xc0360008
    STATUS_IPSEC_THROTTLE_DROP = 0xc0360009
    STATUS_IPSEC_DOSP_BLOCK = 0xc0368000
    STATUS_IPSEC_DOSP_RECEIVED_MULTICAST = 0xc0368001
    STATUS_IPSEC_DOSP_INVALID_PACKET = 0xc0368002
    STATUS_IPSEC_DOSP_STATE_LOOKUP_FAILED = 0xc0368003
    STATUS_IPSEC_DOSP_MAX_ENTRIES = 0xc0368004
    STATUS_IPSEC_DOSP_KEYMOD_NOT_ALLOWED = 0xc0368005
    STATUS_IPSEC_DOSP_MAX_PER_IP_RATELIMIT_QUEUES = 0xc0368006
    STATUS_VOLMGR_MIRROR_NOT_SUPPORTED = 0xc038005b
    STATUS_VOLMGR_RAID5_NOT_SUPPORTED = 0xc038005c
    STATUS_VIRTDISK_PROVIDER_NOT_FOUND = 0xc03a0014
    STATUS_VIRTDISK_NOT_VIRTUAL_DISK = 0xc03a0015
    STATUS_VHD_PARENT_VHD_ACCESS_DENIED = 0xc03a0016
    STATUS_VHD_CHILD_PARENT_SIZE_MISMATCH = 0xc03a0017
    STATUS_VHD_DIFFERENCING_CHAIN_CYCLE_DETECTED = 0xc03a0018
    STATUS_VHD_DIFFERENCING_CHAIN_ERROR_IN_PARENT = 0xc03a0019


# Taken from Winfsp/scr/dll/fuse/errno.i
_POSIX_NTSTATUS_CONVERSIONS = (
    (0, NTSTATUS.STATUS_SUCCESS),
    (1, NTSTATUS.STATUS_ACCESS_DENIED),
    (2, NTSTATUS.STATUS_OBJECT_NAME_NOT_FOUND),
    (3, NTSTATUS.STATUS_PROCEDURE_NOT_FOUND),
    (4, NTSTATUS.STATUS_CANCELLED),
    (5, NTSTATUS.STATUS_IO_DEVICE_ERROR),
    (6, NTSTATUS.STATUS_FILE_INVALID),
    (7, NTSTATUS.STATUS_INSUFFICIENT_RESOURCES),
    (8, NTSTATUS.STATUS_INVALID_IMAGE_FORMAT),
    (9, NTSTATUS.STATUS_INVALID_HANDLE),
    (12, NTSTATUS.STATUS_INSUFFICIENT_RESOURCES),
    (13, NTSTATUS.STATUS_ACCESS_DENIED),
    (14, NTSTATUS.STATUS_ACCESS_VIOLATION),
    (16, NTSTATUS.STATUS_DEVICE_BUSY),
    (17, NTSTATUS.STATUS_OBJECT_NAME_COLLISION),
    (18, NTSTATUS.STATUS_NOT_SAME_DEVICE),
    (19, NTSTATUS.STATUS_NO_SUCH_DEVICE),
    (20, NTSTATUS.STATUS_NOT_A_DIRECTORY),
    (21, NTSTATUS.STATUS_FILE_IS_A_DIRECTORY),
    (22, NTSTATUS.STATUS_INVALID_PARAMETER),
    (23, NTSTATUS.STATUS_TOO_MANY_OPENED_FILES),
    (24, NTSTATUS.STATUS_TOO_MANY_OPENED_FILES),
    (27, NTSTATUS.STATUS_DISK_FULL),
    (28, NTSTATUS.STATUS_DISK_FULL),
    (29, NTSTATUS.STATUS_INVALID_PARAMETER),
    (30, NTSTATUS.STATUS_MEDIA_WRITE_PROTECTED),
    (31, NTSTATUS.STATUS_TOO_MANY_LINKS),
    (32, NTSTATUS.STATUS_PIPE_BROKEN),
    (33, NTSTATUS.STATUS_INVALID_PARAMETER),
    (34, NTSTATUS.STATUS_INVALID_PARAMETER),
    (36, NTSTATUS.STATUS_POSSIBLE_DEADLOCK),
    (38, NTSTATUS.STATUS_NAME_TOO_LONG),
    (39, NTSTATUS.STATUS_LOCK_NOT_GRANTED),
    (40, NTSTATUS.STATUS_INVALID_DEVICE_REQUEST),
    (41, NTSTATUS.STATUS_DIRECTORY_NOT_EMPTY),
    (42, NTSTATUS.STATUS_INVALID_PARAMETER),
    (100, NTSTATUS.STATUS_ADDRESS_ALREADY_ASSOCIATED),
    (103, NTSTATUS.STATUS_CONNECTION_ACTIVE),
    (105, NTSTATUS.STATUS_CANCELLED),
    (106, NTSTATUS.STATUS_CONNECTION_ABORTED),
    (107, NTSTATUS.STATUS_CONNECTION_REFUSED),
    (108, NTSTATUS.STATUS_CONNECTION_RESET),
    (110, NTSTATUS.STATUS_HOST_UNREACHABLE),
    (113, NTSTATUS.STATUS_CONNECTION_ACTIVE),
    (114, NTSTATUS.STATUS_REPARSE_POINT_NOT_RESOLVED),
    (116, NTSTATUS.STATUS_HOST_DOWN),
    (117, NTSTATUS.STATUS_CONNECTION_RESET),
    (118, NTSTATUS.STATUS_NETWORK_UNREACHABLE),
    (119, NTSTATUS.STATUS_INSUFFICIENT_RESOURCES),
    (120, NTSTATUS.STATUS_END_OF_FILE),
    (121, NTSTATUS.STATUS_CONNECTION_INVALID),
    (126, NTSTATUS.STATUS_CONNECTION_INVALID),
    (128, NTSTATUS.STATUS_INVALID_HANDLE),
    (138, NTSTATUS.STATUS_TRANSACTION_TIMED_OUT),
)
_POSIX_TO_NT_LOOKUP = {p: nt for p, nt in _POSIX_NTSTATUS_CONVERSIONS}
_NT_TO_POSIX_LOOKUP = {nt: p for p, nt in _POSIX_NTSTATUS_CONVERSIONS}


def posix_to_ntstatus(code):
    return _POSIX_TO_NT_LOOKUP[code]


def ntstatus_to_posix(code):
    return _NT_TO_POSIX_LOOKUP[code]
